@@ -367,8 +367,6 @@ function io_createNamespace($id, $ns_type='pages') {
  * @author  Andreas Gohr <andi@splitbrain.org>
  */
 function io_makeFileDir($file){
-    global $conf;
-
     $dir = dirname($file);
     if(!@is_dir($dir)){
         io_mkdir_p($dir) || msg("Creating directory $dir failed",-1);
@@ -400,6 +398,56 @@ function io_mkdir_p($target){
     return 0;
 }
 
+/**
+ * Recursively delete a directory
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ * @param string $path
+ * @param bool   $removefiles defaults to false which will delete empty directories only
+ * @return bool
+ */
+function io_rmdir($path, $removefiles = false) {
+    if(!is_string($path) || $path == "") return false;
+    if(!file_exists($path)) return true; // it's already gone or was never there, count as success
+
+    if(is_dir($path) && !is_link($path)) {
+        $dirs  = array();
+        $files = array();
+
+        if(!$dh = @opendir($path)) return false;
+        while(false !== ($f = readdir($dh))) {
+            if($f == '..' || $f == '.') continue;
+
+            // collect dirs and files first
+            if(is_dir("$path/$f") && !is_link("$path/$f")) {
+                $dirs[] = "$path/$f";
+            } else if($removefiles) {
+                $files[] = "$path/$f";
+            } else {
+                return false; // abort when non empty
+            }
+
+        }
+        closedir($dh);
+
+        // now traverse into  directories first
+        foreach($dirs as $dir) {
+            if(!io_rmdir($dir, $removefiles)) return false; // abort on any error
+        }
+
+        // now delete files
+        foreach($files as $file) {
+            if(!@unlink($file)) return false; //abort on any error
+        }
+
+        // remove self
+        return @rmdir($path);
+    } else if($removefiles) {
+        return @unlink($path);
+    }
+    return false;
+}
+
 /**
  * Creates a directory using FTP
  *
