@@ -1,12 +1,14 @@
 <?php
+
 /**
- * Arabic language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Mostafa Hussein <mostafa@gmail.com>
  * @author Yaman Hokan <always.smile.yh@hotmail.com>
  * @author Usama Akkad <uahello@gmail.com>
  * @author uahello@gmail.com
+ * @author Ahmad Abd-Elghany <tolpa1@gmail.com>
+ * @author alhajr <alhajr300@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'rtl';
@@ -31,8 +33,8 @@ $lang['btn_upload']            = 'ارفع';
 $lang['btn_cancel']            = 'ألغ';
 $lang['btn_index']             = 'خريطة موقع';
 $lang['btn_secedit']           = 'حرر';
-$lang['btn_login']             = 'لج';
-$lang['btn_logout']            = 'اخرج';
+$lang['btn_login']             = 'تسجيل الدخول';
+$lang['btn_logout']            = 'خروج';
 $lang['btn_admin']             = 'المدير';
 $lang['btn_update']            = 'حدّث';
 $lang['btn_delete']            = 'احذف';
@@ -42,12 +44,15 @@ $lang['btn_backtomedia']       = 'ارجع إلى اختيار ملف الوسا
 $lang['btn_subscribe']         = 'ادر الاشتراكات';
 $lang['btn_profile']           = 'حدث الملف الشخصي';
 $lang['btn_reset']             = 'صفّر';
-$lang['btn_resendpwd']         = 'ارسل كلمة سر جديدة';
+$lang['btn_resendpwd']         = 'اضبط كلمة سر جديدة';
 $lang['btn_draft']             = 'حرر المسودة';
 $lang['btn_recover']           = 'استرجع المسودة';
 $lang['btn_draftdel']          = 'احذف المسوّدة';
 $lang['btn_revert']            = 'استعد';
 $lang['btn_register']          = 'سجّل';
+$lang['btn_apply']             = 'طبق';
+$lang['btn_media']             = 'مدير الوسائط';
+$lang['btn_deleteuser']        = 'احذف حسابي الخاص';
 $lang['loggedinas']            = 'داخل باسم';
 $lang['user']                  = 'اسم المستخدم';
 $lang['pass']                  = 'كلمة السر';
@@ -59,6 +64,7 @@ $lang['fullname']              = 'الاسم الحقيقي';
 $lang['email']                 = 'البريد الإلكتروني';
 $lang['profile']               = 'الملف الشخصي';
 $lang['badlogin']              = 'عذرا، اسم المشترك أو كلمة السر غير صحيحة';
+$lang['badpassconfirm']        = 'عذراً,كلمة السر غير صحيحة';
 $lang['minoredit']             = 'تعديلات طفيفة';
 $lang['draftdate']             = 'حفظ المسودات آليا مفعّل';
 $lang['nosecedit']             = 'غُيرت الصفحة في هذه الأثناء، معلومات الجزء اصبحت قديمة. حُمُلت كل الصفحة بدلا.';
@@ -75,9 +81,14 @@ $lang['profna']                = 'هذه الويكي لا تدعم تعديل 
 $lang['profnochange']          = 'لا تغييرات، لا شيء ليُعمل.';
 $lang['profnoempty']           = 'غير مسموح باسم مستخدم أو بريد فارغ.';
 $lang['profchanged']           = 'حُدث الملف الشخصي للمستخدم بنجاح.';
+$lang['profnodelete']          = 'هذه الموسوعه لا ندعم حذف الأشخاص';
+$lang['profdeleteuser']        = 'احذف حساب';
+$lang['profdeleted']           = 'حسابك الخاص تم حذفه من هذه الموسوعة';
+$lang['profconfdelete']        = 'أنا أرغب في حذف حسابي من هذه الموسوعة.<br/> 
+هذا الحدث غير ممكن.';
 $lang['pwdforget']             = 'أنسيت كلمة السر؟ احصل على واحدة جديدة';
 $lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور.';
-$lang['resendpwd']             = 'إرسال كلمة مرور';
+$lang['resendpwd']             = 'اضبط كلمة سر جديدة لـ';
 $lang['resendpwdmissing']      = 'عذراّ، يجب أن تملأ كل الحقول.';
 $lang['resendpwdnouser']       = 'عذراً، لم نجد المستخدم هذا في قاعدة بياناتنا.';
 $lang['resendpwdbadauth']      = 'عذراً، رمز التفعيل هذا غير صحيح. نأكد من استخدامك كامل وصلة التأكيد.';
@@ -90,9 +101,10 @@ $lang['searchmedia_in']        = 'ابحث في %s';
 $lang['txt_upload']            = 'اختر ملفاً للرفع';
 $lang['txt_filename']          = 'رفع كـ (اختياري)';
 $lang['txt_overwrt']           = 'اكتب على ملف موجود';
+$lang['maxuploadsize']         = 'الحجم الاقصى %s للملف';
 $lang['lockedby']              = 'مقفلة حاليا لـ';
 $lang['lockexpire']            = 'ينتهي القفل في';
-$lang['willexpire']            = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
+$lang['js']['willexpire']      = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
 $lang['js']['notsavedyet']     = 'التعديلات غير المحفوظة ستفقد.';
 $lang['js']['searchmedia']     = 'ابحث عن ملفات';
 $lang['js']['keepopen']        = 'أبقي النافذة مفتوحة أثناء الاختيار';
@@ -123,7 +135,17 @@ $lang['js']['nosmblinks']      = 'الروابط لمجلدات مشاركة و
 $lang['js']['linkwiz']         = 'مرشد الروابط';
 $lang['js']['linkto']          = 'الرابط إلى :';
 $lang['js']['del_confirm']     = 'هل حقاً تريد حذف البنود المختارة؟';
-$lang['js']['mu_btn']          = 'رفع عدة ملفات في وقت واحد';
+$lang['js']['restore_confirm'] = 'أمتأكد من استرجاع هذه النسخة؟';
+$lang['js']['media_diff']      = 'عرض الفروق:';
+$lang['js']['media_diff_both'] = 'جنبا إلى جنب';
+$lang['js']['media_diff_opacity'] = 'Shine-through';
+$lang['js']['media_diff_portions'] = 'Swipe';
+$lang['js']['media_select']    = 'اختر ملفا...';
+$lang['js']['media_upload_btn'] = 'ارفع';
+$lang['js']['media_done_btn']  = 'تم';
+$lang['js']['media_drop']      = 'اسقط الملف هنا لرفعه';
+$lang['js']['media_cancel']    = 'أزل';
+$lang['js']['media_overwrt']   = 'أكتب فوق الملفات الموجودة';
 $lang['rssfailed']             = 'خطأ ما حدث أثناء جلب ملف التغذية:';
 $lang['nothingfound']          = 'لا يوجد شيء';
 $lang['mediaselect']           = 'ملفات الوسائط';
@@ -168,16 +190,26 @@ $lang['lastmod']               = 'آخر تعديل';
 $lang['by']                    = 'بواسطة';
 $lang['deleted']               = 'حذفت';
 $lang['created']               = 'اُنشئت';
-$lang['restored']              = 'استعيدت نسخة قديمة';
+$lang['restored']              = 'استعيدت نسخة قديمة (%s)';
 $lang['external_edit']         = 'تحرير خارجي';
 $lang['summary']               = 'ملخص التحرير';
 $lang['noflash']               = 'تحتاج إلى<a href="http://www.adobe.com/products/flashplayer/">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
 $lang['download']              = 'نزل Snippet';
+$lang['tools']                 = 'أدوات';
+$lang['user_tools']            = 'أدوات المستخدم';
+$lang['site_tools']            = 'أدوات الموقع';
+$lang['page_tools']            = 'أدوات الصفحة';
+$lang['skip_to_content']       = 'تجاوز إلى المحتوى';
+$lang['sidebar']               = 'العمود الجانبي';
 $lang['mail_newpage']          = 'إضافة صفحة:';
 $lang['mail_changed']          = 'تعديل صفحة:';
 $lang['mail_subscribe_list']   = 'صفحات غيرت في النطاق:';
 $lang['mail_new_user']         = 'مشترك جديد:';
 $lang['mail_upload']           = 'رفع ملف:';
+$lang['changes_type']          = 'أظهر تغييرات الـ';
+$lang['pages_changes']         = 'صفحات';
+$lang['media_changes']         = 'ملفات الوسائط';
+$lang['both_changes']          = 'كلا من الصفحات وملفات الوسائط';
 $lang['qb_bold']               = 'نص عريض';
 $lang['qb_italic']             = 'نص مائل';
 $lang['qb_underl']             = 'نص مسطر';
@@ -207,7 +239,7 @@ $lang['admin_register']        = 'أضف مستخدما جديدا';
 $lang['metaedit']              = 'تحرير البيانات الشمولية ';
 $lang['metasaveerr']           = 'فشلت كتابة البيانات الشمولية';
 $lang['metasaveok']            = 'حُفظت البيانات الشمولية';
-$lang['img_backto']            = 'عودة إلى';
+$lang['btn_img_backto']        = 'عودة إلى %s';
 $lang['img_title']             = 'العنوان';
 $lang['img_caption']           = 'وصف';
 $lang['img_date']              = 'التاريخ';
@@ -218,6 +250,9 @@ $lang['img_copyr']             = 'حقوق النسخ';
 $lang['img_format']            = 'الهيئة';
 $lang['img_camera']            = 'الكمرا';
 $lang['img_keywords']          = 'كلمات مفتاحية';
+$lang['img_width']             = 'العرض';
+$lang['img_height']            = 'الإرتفاع';
+$lang['btn_mediaManager']           = 'اعرض في مدير الوسائط';
 $lang['subscr_subscribe_success'] = 'اضيف %s لقائمة اشتراك %s';
 $lang['subscr_subscribe_error'] = 'خطأ في إضافة %s لقائمة اشتراك %s';
 $lang['subscr_subscribe_noaddress'] = 'ليس هناك عنوان مرتبط بولوجك، لا يمكن اضافتك لقائمة الاشتراك';
@@ -232,10 +267,10 @@ $lang['subscr_m_unsubscribe']  = 'ألغ الاشتراك';
 $lang['subscr_m_subscribe']    = 'اشترك';
 $lang['subscr_m_receive']      = 'استقبال';
 $lang['subscr_style_every']    = 'بريدا على كل تغيير';
-$lang['subscr_style_digest']   = 'بريد ملخص عن تغييرات كل صفحة';
-$lang['subscr_style_list']     = 'قائمة بالصفحات المتغيرة منذ آخر بريد';
-$lang['authmodfailed']         = 'إعدادات تصريح فاسدة، يرجى مراسلة المدير.';
+$lang['subscr_style_digest']   = 'البريد الإلكتروني, ملخص للتغييرات لكل صفحة (كل يوم %.2f)';
+$lang['subscr_style_list']     = 'قائمة بالصفحات التي تم تغييرها منذ آخر بريد الإلكتروني (كل يوم %.2f)';
 $lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
+$lang['authpwdexpire']         = 'ستنتهي صلاحية كلمة السر في %d . عليك بتغييرها سريعا.';
 $lang['i_chooselang']          = 'اختر لغتك';
 $lang['i_installer']           = 'برنامج تنصيب دوكو ويكي';
 $lang['i_wikiname']            = 'اسم الويكي';
@@ -265,23 +300,12 @@ $lang['i_policy']              = 'تصريح ACL مبدئي';
 $lang['i_pol0']                = 'ويكي مفتوحة؛ أي القراءة والكتابة والتحميل مسموحة للجميع';
 $lang['i_pol1']                = 'ويكي عامة؛ أي القراءة للجميع ولكن الكتابة والتحميل للمشتركين المسجلين فقط';
 $lang['i_pol2']                = 'ويكي مغلقة؛ أي القراءة والكتابة والتحميل للمشتركين المسجلين فقط';
+$lang['i_allowreg']            = 'السماح للمستخدمين بتسجيل أنفسهم';
 $lang['i_retry']               = 'إعادة المحاولة';
 $lang['i_license']             = 'اختر الرخصة التي تريد وضع المحتوى تحتها:';
-$lang['mu_intro']              = 'هنا يمكنك رفع ملفات متعددة في وقت واحد. انقر على زر استعرض لاضافتهم إلى الطابور. انقر ارفع عند الانتهاء.';
-$lang['mu_gridname']           = 'اسم الملف';
-$lang['mu_gridsize']           = 'الحجم';
-$lang['mu_gridstat']           = 'الحالة';
-$lang['mu_namespace']          = 'نطاق';
-$lang['mu_browse']             = 'استعرض';
-$lang['mu_toobig']             = 'كبير جدا';
-$lang['mu_ready']              = 'جاهز للرفع';
-$lang['mu_done']               = 'اكتمل';
-$lang['mu_fail']               = 'فشل';
-$lang['mu_authfail']           = 'انتهت الجلسة';
-$lang['mu_progress']           = 'رُفع @PCT@% ';
-$lang['mu_filetypes']          = 'انواع الملفات المسموحة';
-$lang['mu_info']               = 'تم رفع الملفات';
-$lang['mu_lasterr']            = 'آخر خطأ:';
+$lang['i_license_none']        = 'لا تظهر أية معلومات للترخيص';
+$lang['i_pop_field']           = 'من فضلك، ساعدنا على تحسين تجربة دوكي ويكي:';
+$lang['i_pop_label']           = 'مرة واحدة في شهر، إرسال بيانات استخدام المجهول للمطورين دوكي ويكي';
 $lang['recent_global']         = 'انت تراقب حاليا التغييرات داخل نطاق <b>%s</b>. يمكنك أيضا <a href="%s">عرض أحدث تغييرات الويكي كلها</a>.';
 $lang['years']                 = '%d سنة مضت';
 $lang['months']                = '%d شهرا مضى';
@@ -291,3 +315,29 @@ $lang['hours']                 = '%d ساعة مضت';
 $lang['minutes']               = '%d دقيقة مضت';
 $lang['seconds']               = '%d ثانية مضت';
 $lang['wordblock']             = 'لم تحفظ تغييراتك لاحتوائها على نص ممنوع )غثاء(';
+$lang['media_uploadtab']       = 'ارفع';
+$lang['media_searchtab']       = 'ابحث';
+$lang['media_file']            = 'ملف';
+$lang['media_viewtab']         = 'عرض';
+$lang['media_edittab']         = 'تحرير';
+$lang['media_historytab']      = 'التاريخ';
+$lang['media_list_thumbs']     = 'المصغرات';
+$lang['media_list_rows']       = 'صفوف';
+$lang['media_sort_name']       = 'الاسم';
+$lang['media_sort_date']       = 'التاريخ';
+$lang['media_namespaces']      = 'اختر نطاقا';
+$lang['media_files']           = 'الملفات في %s';
+$lang['media_upload']          = 'ارفع إلى %s';
+$lang['media_search']          = 'ابحث في %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s في %s';
+$lang['media_edit']            = 'حرر %s';
+$lang['media_history']         = 'تاريخ %s';
+$lang['media_meta_edited']     = 'عُدلت الميتاداتا';
+$lang['media_perm_read']       = 'عفوا، لست مخولا بقراءة الملفات.';
+$lang['media_perm_upload']     = 'عفوا، لست مخولا برفع الملفات.';
+$lang['media_update']          = 'ارفع إصدارا أحدث';
+$lang['media_restore']         = 'استرجع هذه النسخة';
+$lang['currentns']             = 'مساحة الاسم الحالية';
+$lang['searchresult']          = 'نتيجة البحث';
+$lang['wikimarkup']            = 'علامات الوكي';
