@@ -172,7 +172,7 @@ $lang['admin_register']        = 'İstifadəçi əlavə et';
 $lang['metaedit']              = 'Meta-məlumatlarda düzəliş et';
 $lang['metasaveerr']           = 'Meta-məlumatları yazan zamanı xəta';
 $lang['metasaveok']            = 'Meta-məlumatlar yadda saxlandı';
-$lang['img_backto']            = 'Qayıd';
+$lang['btn_img_backto']        = 'Qayıd %s';
 $lang['img_title']             = 'Başlıq';
 $lang['img_caption']           = 'İmza';
 $lang['img_date']              = 'Tarix';
