@@ -1,20 +1,20 @@
 <?php
+
 /**
- * Bulgarian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Nikolay Vladimirov <nikolay@vladimiroff.com>
  * @author Viktor Usunov <usun0v@mail.bg>
  * @author Kiril <neohidra@gmail.com>
+ * @author Ivan Peltekov <ivan.peltekov@abv.bg>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '"'; //&ldquo;
-$lang['doublequoteclosing']    = '"'; //&rdquo;
-$lang['singlequoteopening']    = '‘'; //&lsquo;
-$lang['singlequoteclosing']    = '’'; //&rsquo;
-$lang['apostrophe']            = '’'; //&rsquo;
-
+$lang['doublequoteopening']    = '"';
+$lang['doublequoteclosing']    = '"';
+$lang['singlequoteopening']    = '‘';
+$lang['singlequoteclosing']    = '’';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Редактиране';
 $lang['btn_source']            = 'Преглед на кода';
 $lang['btn_show']              = 'Преглед на страницата';
@@ -50,7 +50,7 @@ $lang['btn_revert']            = 'Възстановяване';
 $lang['btn_register']          = 'Регистриране';
 $lang['btn_apply']             = 'Прилагане';
 $lang['btn_media']             = 'Диспечер на файлове';
-
+$lang['btn_deleteuser']        = 'Изтриване на профила';
 $lang['loggedinas']            = 'Вписани сте като';
 $lang['user']                  = 'Потребител';
 $lang['pass']                  = 'Парола';
@@ -62,10 +62,10 @@ $lang['fullname']              = 'Истинско име';
 $lang['email']                 = 'Електронна поща';
 $lang['profile']               = 'Потребителски профил';
 $lang['badlogin']              = 'Грешно потребителско име или парола.';
+$lang['badpassconfirm']        = 'За съжаление паролата е грешна';
 $lang['minoredit']             = 'Промените са незначителни';
-$lang['draftdate']             = 'Черновата е автоматично записана на'; // full dformat date will be added
+$lang['draftdate']             = 'Черновата е автоматично записана на';
 $lang['nosecedit']             = 'Страницата бе междувременно променена, презареждане на страницата поради неактуална информация.';
-
 $lang['regmissing']            = 'Моля, попълнете всички полета.';
 $lang['reguexists']            = 'Вече съществува потребител с избраното име.';
 $lang['regsuccess']            = 'Потребителят е създаден, а паролата е пратена по електронната поща.';
@@ -75,12 +75,15 @@ $lang['regbadmail']            = 'Въведеният адрес изглежд
 $lang['regbadpass']            = 'Двете въведени пароли не съвпадат, моля опитайте отново.';
 $lang['regpwmail']             = 'Паролата ви за DokuWiki';
 $lang['reghere']               = 'Все още нямате профил? Направете си';
-
 $lang['profna']                = 'Wiki-то не поддържа промяна на профила';
 $lang['profnochange']          = 'Няма промени.';
-$lang['profnoempty']           = 'Въвеждането на име и ел. поща е задължително';
+$lang['profnoempty']           = 'Въвеждането на име и имейл е задължително';
 $lang['profchanged']           = 'Потребителският профил е обновен успешно.';
-
+$lang['profnodelete']          = 'Изтриването на потребители в това wiki не е възможно';
+$lang['profdeleteuser']        = 'Изтриване на профила';
+$lang['profdeleted']           = 'Вашият профил е премахнат от това wiki ';
+$lang['profconfdelete']        = 'Искам да изтрия профила си от това wiki. <br/>  Веднъж изтрит, профилът не може да бъде възстановен!';
+$lang['profconfdeletemissing'] = 'Не сте поставили отметка в кутията потвърждение';
 $lang['pwdforget']             = 'Забравили сте паролата си? Получете нова';
 $lang['resendna']              = 'Wiki-то не поддържа повторно пращане на паролата.';
 $lang['resendpwd']             = 'Задаване на нова парола за';
@@ -89,10 +92,8 @@ $lang['resendpwdnouser']       = 'Потребителят не е намере
 $lang['resendpwdbadauth']      = 'Кодът за потвърждение е невалиден. Проверете дали сте използвали целия линк за потвърждение.';
 $lang['resendpwdconfirm']      = 'Линк за потвърждение е пратен по електронната поща.';
 $lang['resendpwdsuccess']      = 'Новата ви паролата е пратена по електронната поща.';
-
 $lang['license']               = 'Ако не е посочено друго, съдържанието на Wiki-то е лицензирано под следния лиценз:';
 $lang['licenseok']             = 'Бележка: Редактирайки страницата, Вие се съгласявате да лицензирате промените (които сте направили) под следния лиценз:';
-
 $lang['searchmedia']           = 'Търсене на файл: ';
 $lang['searchmedia_in']        = 'Търсене в %s';
 $lang['txt_upload']            = 'Изберете файл за качване';
@@ -101,7 +102,6 @@ $lang['txt_overwrt']           = 'Презапиши съществуващит
 $lang['maxuploadsize']         = 'Макс. размер за отделните файлове е %s.';
 $lang['lockedby']              = 'В момента е заключена от';
 $lang['lockexpire']            = 'Ще бъде отключена на';
-
 $lang['js']['willexpire']      = 'Страницата ще бъде отключена за редактиране след минута.\nЗа предотвратяване на конфликти, ползвайте бутона "Преглед", за рестартиране на брояча за заключване.';
 $lang['js']['notsavedyet']     = 'Незаписаните промени ще бъдат загубени. Желаете ли да продължите?';
 $lang['js']['searchmedia']     = 'Търсене на файлове';
@@ -140,13 +140,11 @@ $lang['js']['media_diff_portions'] = 'По половинка';
 $lang['js']['media_select']    = 'Изберете файлове...';
 $lang['js']['media_upload_btn'] = 'Качване';
 $lang['js']['media_done_btn']  = 'Готово';
-$lang['js']['media_drop']      = 'Влачете и пуснете файливе тук, за да бъдат качени';
+$lang['js']['media_drop']      = 'Влачете и пуснете файлове тук, за да бъдат качени';
 $lang['js']['media_cancel']    = 'премахване';
 $lang['js']['media_overwrt']   = 'Презапиши съществуващите файлове';
-
 $lang['rssfailed']             = 'Възникна грешка при получаването на емисията: ';
 $lang['nothingfound']          = 'Нищо не е открито.';
-
 $lang['mediaselect']           = 'Файлове';
 $lang['fileupload']            = 'Качване на файлове';
 $lang['uploadsucc']            = 'Качването е успешно';
@@ -166,12 +164,11 @@ $lang['accessdenied']          = 'Нямате необходимите прав
 $lang['mediausage']            = 'Ползвайте следния синтаксис, за да упоменете файла:';
 $lang['mediaview']             = 'Преглед на оригиналния файл';
 $lang['mediaroot']             = 'root';
-$lang['mediaupload']           = 'Качете файл в текущото именно пространство. За създаване на подимено пространство, добавете име преди това на файла като ги разделите с двоеточие в полето "Качи като"';
+$lang['mediaupload']           = 'Качете файл в текущото именно пространство. За създаване на подименно пространство, добавете име преди това на файла като ги разделите с двоеточие в полето "Качи като"';
 $lang['mediaextchange']        = 'Разширението на файла е сменено от .%s на .%s!';
 $lang['reference']             = 'Връзки за';
 $lang['ref_inuse']             = 'Файлът не може да бъде изтрит, защото все още се ползва от следните страници:';
 $lang['ref_hidden']            = 'Някои връзки са към страници, които нямате права да четете';
-
 $lang['hits']                  = 'Съвпадения';
 $lang['quickhits']             = 'Съвпадащи имена на страници';
 $lang['toc']                   = 'Съдържание';
@@ -201,18 +198,15 @@ $lang['site_tools']            = 'Инструменти за сайта';
 $lang['page_tools']            = 'Инструменти за страници';
 $lang['skip_to_content']       = 'към съдържанието';
 $lang['sidebar']               = 'Странична лента';
-
 $lang['mail_newpage']          = 'добавена страница: ';
 $lang['mail_changed']          = 'променена страница: ';
 $lang['mail_subscribe_list']   = 'променени страници в именно пространство: ';
 $lang['mail_new_user']         = 'нов потребител: ';
 $lang['mail_upload']           = 'качен файл: ';
-
 $lang['changes_type']          = 'Преглед на променените';
 $lang['pages_changes']         = 'Страници';
 $lang['media_changes']         = 'Файлове';
 $lang['both_changes']          = 'Страници и файлове';
-
 $lang['qb_bold']               = 'Удебелен текст';
 $lang['qb_italic']             = 'Курсив текст';
 $lang['qb_underl']             = 'Подчертан текст';
@@ -237,15 +231,12 @@ $lang['qb_media']              = 'Добавяне на изображения 
 $lang['qb_sig']                = 'Вмъкване на подпис';
 $lang['qb_smileys']            = 'Усмивчици';
 $lang['qb_chars']              = 'Специални знаци';
-
 $lang['upperns']               = 'към майчиното именно пространство';
-
 $lang['admin_register']        = 'Добавяне на нов потребител';
-
 $lang['metaedit']              = 'Редактиране на метаданни';
 $lang['metasaveerr']           = 'Записването на метаданните се провали';
 $lang['metasaveok']            = 'Метаданните са запазени успешно';
-$lang['img_backto']            = 'Назад към';
+$lang['btn_img_backto']        = 'Назад към %s';
 $lang['img_title']             = 'Заглавие';
 $lang['img_caption']           = 'Надпис';
 $lang['img_date']              = 'Дата';
@@ -258,32 +249,26 @@ $lang['img_camera']            = 'Фотоапарат';
 $lang['img_keywords']          = 'Ключови думи';
 $lang['img_width']             = 'Ширина';
 $lang['img_height']            = 'Височина';
-$lang['img_manager']           = 'Преглед в диспечера на файлове';
-
+$lang['btn_mediaManager']      = 'Преглед в диспечера на файлове';
 $lang['subscr_subscribe_success'] = '%s е добавен към списъка с абониралите се за %s';
 $lang['subscr_subscribe_error'] = 'Грешка при добавянето на %s към списъка с абониралите се за %s';
-$lang['subscr_subscribe_noaddress'] = 'Добавянето ви към списъка с абонати не е възможно поради липсата на свързан адрес (на ел. поща) с профила ви.';
+$lang['subscr_subscribe_noaddress'] = 'Добавянето ви към списъка с абонати не е възможно поради липсата на свързан адрес (имейл) с профила ви.';
 $lang['subscr_unsubscribe_success'] = '%s е премахнат от списъка с абониралите се за %s';
 $lang['subscr_unsubscribe_error'] = 'Грешка при премахването на %s от списъка с абониралите се за %s';
 $lang['subscr_already_subscribed'] = '%s е вече абониран за %s';
 $lang['subscr_not_subscribed'] = '%s не е абониран за %s';
-// Manage page for subscriptions
 $lang['subscr_m_not_subscribed'] = 'Не сте абониран за текущата страницата или именно пространство.';
 $lang['subscr_m_new_header']   = 'Добави абонамент';
 $lang['subscr_m_current_header'] = 'Текущи абонаменти';
 $lang['subscr_m_unsubscribe']  = 'Прекратяване на абонамента';
 $lang['subscr_m_subscribe']    = 'Абониране';
 $lang['subscr_m_receive']      = 'Получаване';
-$lang['subscr_style_every']    = 'на ел. писмо при всяка промяна';
-$lang['subscr_style_digest']   = 'на ел. писмо с обобщение на промените във всяка страница (всеки %.2f дни)';
-$lang['subscr_style_list']     = 'на списък с променените страници от последното ел. писмо (всеки %.2f дни)';
-
-/* auth.class language support */
+$lang['subscr_style_every']    = 'на имейл при всяка промяна';
+$lang['subscr_style_digest']   = 'на имейл с обобщение на промените във всяка страница (всеки %.2f дни)';
+$lang['subscr_style_list']     = 'на списък с променените страници от последния имейл (всеки %.2f дни)';
 $lang['authtempfail']          = 'Удостоверяването на потребители не е възможно за момента. Ако продължи дълго, моля уведомете администратора на Wiki страницата.';
-$lang['authpwdexpire']         = 'Срока на паролата ви ще изтече след %d дни. Препорачително е да я смените по-скоро.';
-
-/* installer strings */
-$lang['i_chooselang']          = 'Изберете вашия изик';
+$lang['authpwdexpire']         = 'Срока на паролата ви ще изтече след %d дни. Препоръчително е да я смените по-скоро.';
+$lang['i_chooselang']          = 'Изберете вашия език';
 $lang['i_installer']           = 'Инсталатор на DokuWiki';
 $lang['i_wikiname']            = 'Име на Wiki-то';
 $lang['i_enableacl']           = 'Ползване на списък за достъп (ACL) [препоръчително]';
@@ -299,19 +284,18 @@ $lang['i_writeerr']            = '<code>%s</code> не можа да бъде с
 $lang['i_badhash']             = 'Файлът dokuwiki.php не може да бъде разпознат или е променен (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - непозволена или празна стойност';
 $lang['i_success']             = 'Настройването приключи успешно. Вече можете да изтриете файла install.php. Продължете към <a href="doku.php?id=wiki:welcome">Вашето ново DokuWiki</a>.';
-
 $lang['i_failure']             = 'Възникнаха грешки при записването на файловете с настройки. Вероятно ще се наложи да ги поправите ръчно,
                                   за да можете да ползвате <a href="doku.php?id=wiki:welcome">Вашето ново DokuWiki</a>.';
 $lang['i_policy']              = 'Първоначална политика за достъп';
 $lang['i_pol0']                = 'Отворено Wiki (всеки може да чете, пише и качва)';
 $lang['i_pol1']                = 'Публично Wiki (всеки може да чете, само регистрирани пишат и качват)';
 $lang['i_pol2']                = 'Затворено Wiki (само регистрирани четат, пишат и качват)';
+$lang['i_allowreg']            = 'Разрешете на потребителите за се регистрират сами';
 $lang['i_retry']               = 'Повторен опит';
 $lang['i_license']             = 'Моля, изберете лиценз под който желаете да публикувате съдържанието:';
 $lang['i_license_none']        = 'Без показване на информация относно лиценза';
 $lang['i_pop_field']           = 'Моля, помогнете за усъвършенстването на DokuWiki:';
 $lang['i_pop_label']           = 'Изпращане на анонимна информация до разработчиците на DokuWiki, веднъж седмично';
-
 $lang['recent_global']         = 'В момента преглеждате промените в именно пространство <b>%s</b>. Може да прегледате и <a href="%s">промените в цялото Wiki</a>.';
 $lang['years']                 = 'преди %d години';
 $lang['months']                = 'преди %d месеца';
@@ -320,9 +304,7 @@ $lang['days']                  = 'преди %d дни';
 $lang['hours']                 = 'преди %d часа';
 $lang['minutes']               = 'преди %d минути';
 $lang['seconds']               = 'преди %d секунди';
-
 $lang['wordblock']             = 'Направените от Вас промени не са съхранени, защото съдържат забранен текст (SPAM).';
-
 $lang['media_uploadtab']       = 'Качване';
 $lang['media_searchtab']       = 'Търсене';
 $lang['media_file']            = 'Файл';
@@ -346,5 +328,5 @@ $lang['media_perm_read']       = 'За съжаление нямате дост
 $lang['media_perm_upload']     = 'За съжаление нямате достатъчно права, за да можете да качите файла.';
 $lang['media_update']          = 'Качване на нова версия';
 $lang['media_restore']         = 'Възстановяване на тази версия';
-
-//Setup VIM: ex: et ts=2 :
+$lang['searchresult']          = 'Резултати от търсенето';
+$lang['plainhtml']             = 'Обикновен HTML';
