@@ -228,7 +228,7 @@ $lang['admin_register']        = 'Afegeix nou usuari';
 $lang['metaedit']              = 'Edita metadades';
 $lang['metasaveerr']           = 'No s\'han pogut escriure les metadades';
 $lang['metasaveok']            = 'S\'han desat les metadades';
-$lang['img_backto']            = 'Torna a';
+$lang['btn_img_backto']        = 'Torna a %s';
 $lang['img_title']             = 'Títol';
 $lang['img_caption']           = 'Peu d\'imatge';
 $lang['img_date']              = 'Data';
