@@ -246,7 +246,7 @@ $lang['admin_register']        = 'Tilføj ny bruger';
 $lang['metaedit']              = 'Rediger metadata';
 $lang['metasaveerr']           = 'Skrivning af metadata fejlede';
 $lang['metasaveok']            = 'Metadata gemt';
-$lang['img_backto']            = 'Tilbage til';
+$lang['btn_img_backto']            = 'Tilbage til %s';
 $lang['img_title']             = 'Titel';
 $lang['img_caption']           = 'Billedtekst';
 $lang['img_date']              = 'Dato';
@@ -259,7 +259,7 @@ $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Emneord';
 $lang['img_width']             = 'Bredde';
 $lang['img_height']            = 'Højde';
-$lang['img_manager']           = 'Vis i Media Manager';
+$lang['btn_mediaManager']           = 'Vis i Media Manager';
 $lang['subscr_subscribe_success'] = 'Tilføjede %s til abonnement listen for %s';
 $lang['subscr_subscribe_error'] = 'Fejl ved tilføjelse af %s til abonnement listen for %s';
 $lang['subscr_subscribe_noaddress'] = 'Der er ikke nogen addresse forbundet til din bruger, så du kan ikke blive tilføjet til abonnement listen';
