@@ -52,6 +52,8 @@ $lang['btn_register']          = 'Register';
 $lang['btn_apply']             = 'Apply';
 $lang['btn_media']             = 'Media Manager';
 $lang['btn_deleteuser']        = 'Remove My Account';
+$lang['btn_img_backto']        = 'Back to %s';
+$lang['btn_mediaManager']      = 'View in media manager';
 
 $lang['loggedinas']            = 'Logged in as';
 $lang['user']                  = 'Username';
@@ -191,6 +193,11 @@ $lang['difflink']              = 'Link to this comparison view';
 $lang['diff_type']             = 'View differences:';
 $lang['diff_inline']           = 'Inline';
 $lang['diff_side']             = 'Side by Side';
+$lang['diffprevrev']           = 'Previous revision';
+$lang['diffnextrev']           = 'Next revision';
+$lang['difflastrev']           = 'Last revision';
+$lang['diffbothprevrev']       = 'Both sides previous revision';
+$lang['diffbothnextrev']       = 'Both sides next revision';
 $lang['line']                  = 'Line';
 $lang['breadcrumb']            = 'Trace';
 $lang['youarehere']            = 'You are here';
@@ -224,7 +231,7 @@ $lang['both_changes']          = 'Both pages and media files';
 $lang['qb_bold']               = 'Bold Text';
 $lang['qb_italic']             = 'Italic Text';
 $lang['qb_underl']             = 'Underlined Text';
-$lang['qb_code']               = 'Code Text';
+$lang['qb_code']               = 'Monospaced Text';
 $lang['qb_strike']             = 'Strike-through Text';
 $lang['qb_h1']                 = 'Level 1 Headline';
 $lang['qb_h2']                 = 'Level 2 Headline';
@@ -253,7 +260,6 @@ $lang['admin_register']        = 'Add new user';
 $lang['metaedit']              = 'Edit Metadata';
 $lang['metasaveerr']           = 'Writing metadata failed';
 $lang['metasaveok']            = 'Metadata saved';
-$lang['img_backto']            = 'Back to';
 $lang['img_title']             = 'Title';
 $lang['img_caption']           = 'Caption';
 $lang['img_date']              = 'Date';
@@ -266,7 +272,6 @@ $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Keywords';
 $lang['img_width']             = 'Width';
 $lang['img_height']            = 'Height';
-$lang['img_manager']           = 'View in media manager';
 
 $lang['subscr_subscribe_success']   = 'Added %s to subscription list for %s';
 $lang['subscr_subscribe_error']     = 'Error adding %s to subscription list for %s';
