@@ -37,13 +37,13 @@ $lang['btn_secedit']           = 'Redakti';
 $lang['btn_login']             = 'Ensaluti';
 $lang['btn_logout']            = 'Elsaluti';
 $lang['btn_admin']             = 'Administri';
-$lang['btn_update']            = 'Ĝisdatigi';
+$lang['btn_update']            = 'Aktualigi';
 $lang['btn_delete']            = 'Forigi';
 $lang['btn_back']              = 'Retroiri';
 $lang['btn_backlink']          = 'Retroligoj';
 $lang['btn_backtomedia']       = 'Retroiri al elekto de dosiero';
 $lang['btn_subscribe']         = 'Aliĝi al paĝaj modifoj';
-$lang['btn_profile']           = 'Ĝisdatigi profilon';
+$lang['btn_profile']           = 'Aktualigi profilon';
 $lang['btn_reset']             = 'Rekomenci';
 $lang['btn_resendpwd']         = 'Sendi novan pasvorton';
 $lang['btn_draft']             = 'Redakti skizon';
@@ -53,7 +53,9 @@ $lang['btn_revert']            = 'Restarigi';
 $lang['btn_register']          = 'Registriĝi';
 $lang['btn_apply']             = 'Apliki';
 $lang['btn_media']             = 'Medio-administrilo';
-$lang['btn_deleteuser']        = 'Forigi mian aliĝon';
+$lang['btn_deleteuser']        = 'Forigi mian konton';
+$lang['btn_img_backto']        = 'Iri reen al %s';
+$lang['btn_mediaManager']      = 'Rigardi en aŭdvidaĵ-administrilo';
 $lang['loggedinas']            = 'Ensalutinta kiel';
 $lang['user']                  = 'Uzant-nomo';
 $lang['pass']                  = 'Pasvorto';
@@ -81,7 +83,7 @@ $lang['reghere']               = 'Se vi ne havas konton, vi povas akiri ĝin';
 $lang['profna']                = 'Tiu ĉi vikio ne ebligas modifon en la profiloj.';
 $lang['profnochange']          = 'Neniu ŝanĝo, nenio farinda.';
 $lang['profnoempty']           = 'Malplena nomo aŭ retadreso ne estas permesata.';
-$lang['profchanged']           = 'La profilo de la uzanto sukcese ĝisdatiĝis.';
+$lang['profchanged']           = 'La profilo de la uzanto sukcese aktualiĝis.';
 $lang['profnodelete']          = 'Tiu ĉi vikio ne subtenas forigo de uzantoj';
 $lang['profdeleteuser']        = 'Forigi aliĝon';
 $lang['profdeleted']           = 'Via uzant-aliĝo estis forigata de tiu ĉi vikio';
@@ -104,7 +106,7 @@ $lang['txt_filename']          = 'Alŝuti kiel (laŭvole)';
 $lang['txt_overwrt']           = 'Anstataŭigi ekzistantan dosieron';
 $lang['maxuploadsize']         = 'Alŝuto maks. %s po dosiero.';
 $lang['lockedby']              = 'Nune ŝlosita de';
-$lang['lockexpire']            = 'Ŝlosado ĉesos en';
+$lang['lockexpire']            = 'Ŝlosado ĉesos je';
 $lang['js']['willexpire']      = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempokontrolon de la ŝlosado, premu la butonon "Antaŭrigardi".';
 $lang['js']['notsavedyet']     = 'Ne konservitaj modifoj perdiĝos.
 Ĉu vi certe volas daŭrigi la procezon?';
@@ -184,6 +186,11 @@ $lang['difflink']              = 'Ligilo al kompara rigardo';
 $lang['diff_type']             = 'Rigardi malsamojn:';
 $lang['diff_inline']           = 'Samlinie';
 $lang['diff_side']             = 'Apude';
+$lang['diffprevrev']           = 'Antaŭa revizio';
+$lang['diffnextrev']           = 'Sekva revizio';
+$lang['difflastrev']           = 'Lasta revizio';
+$lang['diffbothprevrev']       = 'Sur ambaŭ flankoj antaŭa revizio';
+$lang['diffbothnextrev']       = 'Sur ambaŭ flankoj sekva revizio';
 $lang['line']                  = 'Linio';
 $lang['breadcrumb']            = 'Paŝoj';
 $lang['youarehere']            = 'Vi estas ĉi tie';
@@ -240,7 +247,6 @@ $lang['admin_register']        = 'Aldoni novan uzanton';
 $lang['metaedit']              = 'Redakti metadatumaron';
 $lang['metasaveerr']           = 'La konservo de metadatumaro malsukcesis';
 $lang['metasaveok']            = 'La metadatumaro konserviĝis';
-$lang['img_backto']            = 'Iri reen al';
 $lang['img_title']             = 'Titolo';
 $lang['img_caption']           = 'Priskribo';
 $lang['img_date']              = 'Dato';
@@ -253,7 +259,6 @@ $lang['img_camera']            = 'Kamerao';
 $lang['img_keywords']          = 'Ŝlosilvortoj';
 $lang['img_width']             = 'Larĝeco';
 $lang['img_height']            = 'Alteco';
-$lang['img_manager']           = 'Rigardi en aŭdvidaĵ-administrilo';
 $lang['subscr_subscribe_success'] = 'Aldonis %s al la abonlisto por %s';
 $lang['subscr_subscribe_error'] = 'Eraro dum aldono de %s al la abonlisto por %s';
 $lang['subscr_subscribe_noaddress'] = 'Ne estas adreso ligita al via ensaluto, ne eblas aldoni vin al la abonlisto';
@@ -293,6 +298,7 @@ $lang['i_policy']              = 'Komenca ACL-a agordo';
 $lang['i_pol0']                = 'Malferma Vikio (legi, skribi, alŝuti povas ĉiuj)';
 $lang['i_pol1']                = 'Publika Vikio (legi povas ĉiuj, skribi kaj alŝuti povas registritaj uzantoj)';
 $lang['i_pol2']                = 'Ferma Vikio (legi, skribi, alŝuti nur povas registritaj uzantoj)';
+$lang['i_allowreg']            = 'Permesi al uzantoj registri sin mem';
 $lang['i_retry']               = 'Reprovi';
 $lang['i_license']             = 'Bonvolu elekti la permesilon, sub kiun vi volas meti vian enhavon:';
 $lang['i_license_none']        = 'Ne montri licencinformojn';
