@@ -1,13 +1,15 @@
 <?php
+
 /**
- * Estonian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Oliver S6ro <seem.iges@mail.ee>
  * @author Aari Juhanson <aari@vmg.vil.ee>
  * @author Kaiko Kaur <kaiko@kultuur.edu.ee>
  * @author kristian.kankainen@kuu.la
  * @author Rivo Zängov <eraser@eraser.ee>
+ * @author Janar Leas <janarleas@gmail.com>
+ * @author Janar Leas <janar.leas@eesti.ee>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -43,11 +45,15 @@ $lang['btn_backtomedia']       = 'Tagasi faili valikusse';
 $lang['btn_subscribe']         = 'Jälgi seda lehte (teated meilile)';
 $lang['btn_profile']           = 'Minu info';
 $lang['btn_reset']             = 'Taasta';
+$lang['btn_resendpwd']         = 'Sea uus salasõna';
 $lang['btn_draft']             = 'Toimeta mustandit';
 $lang['btn_recover']           = 'Taata mustand';
 $lang['btn_draftdel']          = 'Kustuta mustand';
 $lang['btn_revert']            = 'Taasta';
 $lang['btn_register']          = 'Registreeri uus kasutaja';
+$lang['btn_apply']             = 'Kinnita';
+$lang['btn_media']             = 'Meedia haldur';
+$lang['btn_deleteuser']        = 'Eemalda minu konto';
 $lang['loggedinas']            = 'Logis sisse kui';
 $lang['user']                  = 'Kasutaja';
 $lang['pass']                  = 'Parool';
@@ -59,8 +65,10 @@ $lang['fullname']              = 'Täielik nimi';
 $lang['email']                 = 'E-post';
 $lang['profile']               = 'Kasutaja info';
 $lang['badlogin']              = 'Oops, Sinu kasutajanimi või parool oli vale.';
+$lang['badpassconfirm']        = 'Väär salasõna';
 $lang['minoredit']             = 'Ebaolulised muudatused';
 $lang['draftdate']             = 'Mustand automaatselt salvestatud';
+$lang['nosecedit']             = 'Leht on vahepeal muutunud, jaotiste teave osutus aegunuks sestap laeti tervelehekülg.';
 $lang['regmissing']            = 'Kõik väljad tuleb ära täita.';
 $lang['reguexists']            = 'Tegelikult on sellise nimega kasutaja juba olemas.';
 $lang['regsuccess']            = 'Kasutaja sai tehtud. Parool saadeti Sulle e-posti aadressil.';
@@ -76,21 +84,30 @@ $lang['profna']                = 'Viki ei toeta profiili muudatusi';
 $lang['profnochange']          = 'Muutused puuduvad.';
 $lang['profnoempty']           = 'Tühi nimi ega meiliaadress pole lubatud.';
 $lang['profchanged']           = 'Kasutaja info edukalt muudetud';
+$lang['profnodelete']          = 'See wiki ei toeta kasutajate kustutamist';
+$lang['profdeleteuser']        = 'Kustuta konto';
+$lang['profdeleted']           = 'Sinu kasutajakonto on sellest wikist kustutatud';
+$lang['profconfdelete']        = 'Soovin sellest wikist oma konnto eemaldada. <br/> See tegevus on taastamatu.';
+$lang['profconfdeletemissing'] = 'Kinnituse valikkast märkimata.';
 $lang['pwdforget']             = 'Unustasid parooli? Tee uus';
 $lang['resendna']              = 'See wiki ei toeta parooli taassaatmist.';
+$lang['resendpwd']             = 'Sea uus salasõna';
 $lang['resendpwdmissing']      = 'Khmm... Sa pead täitma kõik väljad.';
 $lang['resendpwdnouser']       = 'Aga sellist kasutajat ei ole.';
 $lang['resendpwdbadauth']      = 'See autentimiskood ei ole õige. Kontrolli, et kopeerisid terve lingi.';
 $lang['resendpwdconfirm']      = 'Kinnituslink saadeti meilile.';
 $lang['resendpwdsuccess']      = 'Uus parool saadeti Sinu meilile.';
+$lang['license']               = 'Kus pole öeldud teisiti, kehtib selle wiki sisule järgmine leping:';
+$lang['licenseok']             = 'Teadmiseks: Toimetades seda lehte, nõustud avaldama oma sisu järgmise lepingu alusel:';
 $lang['searchmedia']           = 'Otsi failinime:';
 $lang['searchmedia_in']        = 'Otsi %s';
 $lang['txt_upload']            = 'Vali fail, mida üles laadida';
 $lang['txt_filename']          = 'Siseta oma Wikinimi (soovituslik)';
 $lang['txt_overwrt']           = 'Kirjutan olemasoleva faili üle';
+$lang['maxuploadsize']         = 'Üleslaadimiseks lubatu enim %s faili kohta.';
 $lang['lockedby']              = 'Praegu on selle lukustanud';
 $lang['lockexpire']            = 'Lukustus aegub';
-$lang['js']['willexpire']            = 'Teie lukustus selle lehe toimetamisele aegub umbes minuti pärast.\nIgasugu  probleemide vältimiseks kasuta eelvaate nuppu, et lukustusarvesti taas tööle panna.';
+$lang['js']['willexpire']      = 'Teie lukustus selle lehe toimetamisele aegub umbes minuti pärast.\nIgasugu  probleemide vältimiseks kasuta eelvaate nuppu, et lukustusarvesti taas tööle panna.';
 $lang['js']['notsavedyet']     = 'Sul on seal salvestamata muudatusi, mis kohe kõige kaduva teed lähevad.
 Kas Sa ikka tahad edasi liikuda?';
 $lang['js']['searchmedia']     = 'Otsi faile';
@@ -122,6 +139,17 @@ Siiski võid kopeerida ja asetada lingi.';
 $lang['js']['linkwiz']         = 'Lingi nõustaja';
 $lang['js']['linkto']          = 'Lingi:';
 $lang['js']['del_confirm']     = 'Kas kustutame selle kirje?';
+$lang['js']['restore_confirm'] = 'Tõesti taastad selle järgu?';
+$lang['js']['media_diff']      = 'Vaatle erisusi:';
+$lang['js']['media_diff_both'] = 'Kõrvuti';
+$lang['js']['media_diff_opacity'] = 'Kuma läbi';
+$lang['js']['media_diff_portions'] = 'Puhasta';
+$lang['js']['media_select']    = 'Vali failid…';
+$lang['js']['media_upload_btn'] = 'Lae üles';
+$lang['js']['media_done_btn']  = 'Valmis';
+$lang['js']['media_drop']      = 'Üleslaadimiseks viska failid siia';
+$lang['js']['media_cancel']    = 'eemalda';
+$lang['js']['media_overwrt']   = 'Asenda olemasolevad failid';
 $lang['rssfailed']             = 'Sinu soovitud info ammutamisel tekkis viga: ';
 $lang['nothingfound']          = 'Oops, aga mitte muhvigi ei leitud.';
 $lang['mediaselect']           = 'Hunnik faile';
@@ -131,6 +159,8 @@ $lang['uploadfail']            = 'Üleslaadimine läks nässu. Äkki pole Sa sel
 $lang['uploadwrong']           = 'Ei saa Sa midagi üles laadida. Oops, aga seda tüüpi faili sul lihtsalt ei lubata üles laadida';
 $lang['uploadexist']           = 'Fail on juba olemas. Midagi ei muudetud.';
 $lang['uploadbadcontent']      = 'Üles laaditu ei sobinud %s faililaiendiga.';
+$lang['uploadspam']            = 'Üleslaadimine tõrjuti rämpssisu vältija poolt.';
+$lang['uploadxss']             = 'Üleslaadimine tõrjuti kahtlase sisu võimaluse tõttu';
 $lang['uploadsize']            = 'Üles laaditud fail on liiga suur (maksimaalne suurus on %s).';
 $lang['deletesucc']            = 'Fail nimega "%s" sai kustutatud.';
 $lang['deletefail']            = 'Faili nimega "%s" ei kustutatud (kontrolli õigusi).';
@@ -141,7 +171,7 @@ $lang['accessdenied']          = 'Ligipääs keelatud.';
 $lang['mediausage']            = 'Kasuta järgmist kirjapilti sellele failile viitamaks:';
 $lang['mediaview']             = 'Vaata faili algsel kujul.';
 $lang['mediaroot']             = 'juur';
-$lang['mediaupload']           = 'Lae fail sellesse nimeruumi (kataloogi). Et tekitada veel alam nimeruum kasuta koolonit Wiki nimes.';
+$lang['mediaupload']           = 'Lae fail sellesse nimeruumi (kataloogi). Loomaks täiendavaid alam-nimeruume, kasuta wiki-nime ja nimeruumide eraldamiseks koolonit.';
 $lang['mediaextchange']        = 'Faili laiend .%s-st %s-ks!';
 $lang['reference']             = 'Viited';
 $lang['ref_inuse']             = 'Seda faili ei saa kustutada, sest teda kasutavad järgmised lehed:';
@@ -155,6 +185,7 @@ $lang['diff']                  = 'Näita erinevusi hetkel kehtiva versiooniga';
 $lang['diff2']                 = 'Näita valitud versioonide erinevusi';
 $lang['difflink']              = 'Lõlita võrdlemise vaatele';
 $lang['diff_type']             = 'Vaata erinevusi:';
+$lang['diff_inline']           = 'Jooksvalt';
 $lang['diff_side']             = 'Kõrvuti';
 $lang['line']                  = 'Rida';
 $lang['breadcrumb']            = 'Käidud rada';
@@ -166,9 +197,22 @@ $lang['created']               = 'tekitatud';
 $lang['restored']              = 'vana versioon taastatud (%s)';
 $lang['external_edit']         = 'väline muutmine';
 $lang['summary']               = 'kokkuvõte muudatustest';
+$lang['noflash']               = 'Sele sisu vaatamisesks on vajalik <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Laiendus</a>.';
+$lang['tools']                 = 'Tööriistad';
+$lang['user_tools']            = 'Kasutaja tarvikud';
+$lang['site_tools']            = 'Lehe tööriistad';
+$lang['page_tools']            = 'Lehekülje tarvikud';
+$lang['skip_to_content']       = 'mine sisule';
+$lang['sidebar']               = 'Külgriba';
 $lang['mail_newpage']          = 'leht lisatud:';
 $lang['mail_changed']          = 'leht muudetud';
+$lang['mail_subscribe_list']   = 'muutunud leheküljed nimeruumis:';
 $lang['mail_new_user']         = 'Uus kasutaja:';
+$lang['mail_upload']           = 'üles laetud fail:';
+$lang['changes_type']          = 'Näita mmutuseid';
+$lang['pages_changes']         = 'Leheküljed';
+$lang['media_changes']         = 'Meedia failid';
+$lang['both_changes']          = 'Mõlemid, leheküljed ja meedia failid';
 $lang['qb_bold']               = 'Rasvane kiri';
 $lang['qb_italic']             = 'Kaldkiri';
 $lang['qb_underl']             = 'Alajoonega kiri';
@@ -193,11 +237,12 @@ $lang['qb_media']              = 'Lisa pilte ja muid faile';
 $lang['qb_sig']                = 'Lisa allkiri!';
 $lang['qb_smileys']            = 'Emotikonid';
 $lang['qb_chars']              = 'Erisümbolid';
+$lang['upperns']               = 'mine ülemisse nimeruumi';
 $lang['admin_register']        = 'Lisa kasutaja';
 $lang['metaedit']              = 'Muuda lisainfot';
 $lang['metasaveerr']           = 'Lisainfo salvestamine läks untsu.';
 $lang['metasaveok']            = 'Lisainfo salvestatud';
-$lang['img_backto']            = 'Tagasi';
+$lang['btn_img_backto']            = 'Tagasi %s';
 $lang['img_title']             = 'Tiitel';
 $lang['img_caption']           = 'Kirjeldus';
 $lang['img_date']              = 'Kuupäev';
@@ -208,7 +253,26 @@ $lang['img_copyr']             = 'Autoriõigused';
 $lang['img_format']            = 'Formaat';
 $lang['img_camera']            = 'Kaamera';
 $lang['img_keywords']          = 'Võtmesõnad';
+$lang['img_width']             = 'Laius';
+$lang['img_height']            = 'Kõrgus';
+$lang['img_manager']           = 'Näita meediahalduris';
+$lang['subscr_subscribe_success'] = '%s lisati %s tellijaks';
+$lang['subscr_subscribe_error'] = 'Viga %s lisamisel %s tellijaks';
+$lang['subscr_subscribe_noaddress'] = 'Sinu kasutajaga pole seotud ühtegi aadressi, seega ei saa sind tellijaks lisada';
+$lang['subscr_unsubscribe_success'] = '%s eemaldati %s tellijatest';
+$lang['subscr_unsubscribe_error'] = 'Viga %s eemaldamisel %s tellijatest';
+$lang['subscr_already_subscribed'] = '%s on juba %s tellija';
+$lang['subscr_not_subscribed'] = '%s pole %s tellija';
+$lang['subscr_m_not_subscribed'] = 'Sina pole hetkel selle lehekülje ega nimeruumi tellija.';
+$lang['subscr_m_new_header']   = 'Lisa tellimus';
+$lang['subscr_m_current_header'] = 'Hetkel tellitud';
+$lang['subscr_m_unsubscribe']  = 'Eemalda tellimus';
+$lang['subscr_m_subscribe']    = 'Telli';
+$lang['subscr_style_every']    = 'igast toimetamisest teavitab ekiri';
+$lang['subscr_style_digest']   = 'kokkuvõte ekirjaga toimetamistest igal leheküljel (iga %.2f päeva järel)';
+$lang['subscr_style_list']     = 'Peale viimast ekirja (iga %.2f päeva järel) toimetaud lehekülgede loend.';
 $lang['authtempfail']          = 'Kasutajate autentimine on ajutiselt rivist väljas. Kui see olukord mõne aja jooksul ei parane, siis teavita sellest serveri haldajat.';
+$lang['authpwdexpire']         = 'Sinu salasõna aegub %päeva pärast, võiksid seda peatselt muuta.';
 $lang['i_chooselang']          = 'Vali keel';
 $lang['i_installer']           = 'DokuWiki paigaldaja';
 $lang['i_wikiname']            = 'Wiki nimi';
@@ -218,9 +282,11 @@ $lang['i_problems']            = 'Paigaldaja leidis mõned vead, mis on allpool
 $lang['i_modified']            = 'Õnnetuste vältimiseks läheb see skript käima ainult värskelt paigaldatud ja muutmata Dokuwiki peal.
                        Sa peaksid ilmselt kogu koodi uuesti lahti pakkima. Vaata ka <a href="http://dokuwiki.org/install">Dokuwiki installeerimis juhendit</a>';
 $lang['i_funcna']              = 'PHP funktsiooni <code>%s</code> ei ole olemas.võibolla sinu serveri hooldaja on selle mingil põhjusel keelanud?';
+$lang['i_phpver']              = 'Sinu PHP versioon <code>%s</code> on vanem nõutavast <code>%s</code>. Pead oma paigaldatud PHP-d uuendama.';
 $lang['i_permfail']            = 'Dokuwiki ei saa kirjutada faili <code>%s</code>. Kontrolli serveris failide õigused üle.';
 $lang['i_confexists']          = '<code>%s</code> on juba olemas';
 $lang['i_writeerr']            = 'Faili <code>%s</code> ei lubata tekitada. Kontrolli kataloogi ja faili õigusi.';
+$lang['i_badhash']             = 'Tundmatu või muutunud dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - lubamatu või tühi väärtus';
 $lang['i_success']             = 'Seadistamine on õnnelikult lõpule viidud. Sa võid nüüd kustutada faili install.php. Alusta oma <a href="doku.php?id=wiki:welcome">uue DokuWiki</a> täitmist.';
 $lang['i_failure']             = 'Konfiguratsiooni faili kirjutamisel esines vigu. Võimalik, et pead need käsitsi parandama enne <a href="doku.php?id=wiki:welcome">uue DokuWiki</a> täitma asumist.';
@@ -228,4 +294,45 @@ $lang['i_policy']              = 'Wiki õiguste algne poliitika';
 $lang['i_pol0']                = 'Avatud (lugemine, kirjutamine ja üleslaadimine kõigile lubatud)';
 $lang['i_pol1']                = 'Avalikuks lugemiseks (lugeda saavad kõik, kirjutada ja üles laadida vaid registreeritud kasutajad)';
 $lang['i_pol2']                = 'Suletud (kõik õigused, kaasaarvatud lugemine on lubatud vaid registreeritud kasutajatele)';
+$lang['i_allowreg']            = 'Luba kasutajail endid ise arvele võtta';
 $lang['i_retry']               = 'Proovi uuesti';
+$lang['i_license']             = 'Vali leping, mille alusel wiki sisu avaldatakse:';
+$lang['i_license_none']        = 'Ära näita mingit lepingu teavet';
+$lang['i_pop_field']           = 'Aitake meil täiendada DokuWiki kasutuskogemsut:';
+$lang['i_pop_label']           = 'Kord kuus, saada DokuWiki arendajatele anonüümseid kasutus andmeid.';
+$lang['recent_global']         = 'Uurid hetkel nimeruumi <b>%s</b> muudatusi. Võid uurida ka <a href="%s">kogu selle wiki</a> muudatusi.';
+$lang['years']                 = '%d aasta eest';
+$lang['months']                = '%d kuu eest';
+$lang['weeks']                 = '%d nädala eest';
+$lang['days']                  = '%d päeva eest';
+$lang['hours']                 = '%d tunni eest';
+$lang['minutes']               = '%d minuti eest';
+$lang['seconds']               = '%d sekundi eest';
+$lang['wordblock']             = 'Sinu toimetus jäeti muutmata tõrjutud teksti tõttu (rämpspost?).';
+$lang['media_uploadtab']       = 'Lae-↑ ';
+$lang['media_searchtab']       = 'Otsi';
+$lang['media_file']            = 'Fail';
+$lang['media_viewtab']         = 'Vaata';
+$lang['media_edittab']         = 'Toimeta';
+$lang['media_historytab']      = 'Ajalugu';
+$lang['media_list_thumbs']     = 'Pisipildid';
+$lang['media_list_rows']       = 'Ridu';
+$lang['media_sort_name']       = 'Nimi';
+$lang['media_sort_date']       = 'Kuupäev';
+$lang['media_namespaces']      = 'Vali nimeruum';
+$lang['media_files']           = 'Failid %s-is';
+$lang['media_upload']          = 'Lae %s-ssi';
+$lang['media_search']          = 'Leia %s-st';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s asub %s-s';
+$lang['media_edit']            = 'Muuda %s-i';
+$lang['media_history']         = '%s ajalugu';
+$lang['media_meta_edited']     = 'toimetati päiseteavet';
+$lang['media_perm_read']       = 'Sul pole piisavaid õigusi failide vaatamiseks';
+$lang['media_perm_upload']     = 'Sul pole piisavaid õigusi failide üleslaadimiseks';
+$lang['media_update']          = 'Lea üles uus järk';
+$lang['media_restore']         = 'Ennista sellele järgule';
+$lang['currentns']             = 'Hetke nimeruum';
+$lang['searchresult']          = 'Otsingu tulemus';
+$lang['plainhtml']             = 'Liht-HTML';
+$lang['wikimarkup']            = 'Wiki märgistus';
