@@ -227,7 +227,7 @@ $lang['admin_register']        = 'Erabiltzaile berria gehitu';
 $lang['metaedit']              = 'Metadatua Aldatu';
 $lang['metasaveerr']           = 'Metadatuaren idazketak huts egin du';
 $lang['metasaveok']            = 'Metadatua gordea';
-$lang['img_backto']            = 'Atzera hona';
+$lang['btn_img_backto']            = 'Atzera hona %s';
 $lang['img_title']             = 'Izenburua';
 $lang['img_caption']           = 'Epigrafea';
 $lang['img_date']              = 'Data';
@@ -240,7 +240,7 @@ $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Hitz-gakoak';
 $lang['img_width']             = 'Zabalera';
 $lang['img_height']            = 'Altuera';
-$lang['img_manager']           = 'Media kudeatzailean ikusi';
+$lang['btn_mediaManager']           = 'Media kudeatzailean ikusi';
 $lang['subscr_subscribe_success'] = '%s gehitua %s-ren harpidetza zerrendara';
 $lang['subscr_subscribe_error'] = 'Errorea %s gehitzen %s-ren harpidetza zerrendara';
 $lang['subscr_subscribe_noaddress'] = 'Ez dago helbiderik zure login-arekin lotuta, ezin zara harpidetza zerrendara gehitua izan.';
