@@ -1,12 +1,14 @@
 <?php
+
 /**
- * Finnish language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Petteri <petteri@gmail.com>
  * @author Matti Pöllä <mpo@iki.fi>
- * @author otto@valjakko.net
  * @author Otto Vainio <otto@valjakko.net>
+ * @author Teemu Mattila <ghcsystems@gmail.com>
+ * @author Sami Olmari <sami@olmari.fi>
+ * @author Rami Lehti <rammer@ipi.fi>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -40,15 +42,17 @@ $lang['btn_back']              = 'Takaisin';
 $lang['btn_backlink']          = 'Paluulinkit';
 $lang['btn_backtomedia']       = 'Takaisin mediatiedostojen valintaan';
 $lang['btn_subscribe']         = 'Tilaa muutokset';
-$lang['btn_unsubscribe']       = 'Lopeta muutosten tilaus';
-$lang['btn_subscribens']       = 'Tilaa nimiavaruuden muutokset';
-$lang['btn_unsubscribens']     = 'Lopeta nimiavaruuden muutosten tilaus';
 $lang['btn_profile']           = 'Päivitä profiili';
 $lang['btn_reset']             = 'Tyhjennä';
-$lang['btn_resendpwd']         = 'Lähetä uusi salasana';
+$lang['btn_resendpwd']         = 'Aseta uusi salasana';
 $lang['btn_draft']             = 'Muokkaa luonnosta';
 $lang['btn_recover']           = 'Palauta luonnos';
 $lang['btn_draftdel']          = 'Poista luonnos';
+$lang['btn_revert']            = 'palauta';
+$lang['btn_register']          = 'Rekisteröidy';
+$lang['btn_apply']             = 'Toteuta';
+$lang['btn_media']             = 'Media manager';
+$lang['btn_deleteuser']        = 'Poista tilini';
 $lang['loggedinas']            = 'Kirjautunut nimellä';
 $lang['user']                  = 'Käyttäjänimi';
 $lang['pass']                  = 'Salasana';
@@ -58,9 +62,9 @@ $lang['passchk']               = 'uudelleen';
 $lang['remember']              = 'Muista minut';
 $lang['fullname']              = 'Koko nimi';
 $lang['email']                 = 'Sähköposti';
-$lang['register']              = 'Rekisteröidy';
 $lang['profile']               = 'Käyttäjän profiili';
 $lang['badlogin']              = 'Käyttäjänimi tai salasana oli väärä.';
+$lang['badpassconfirm']        = 'Valitan. Salasana oli väärin';
 $lang['minoredit']             = 'Pieni muutos';
 $lang['draftdate']             = 'Luonnos tallennettu automaattisesti';
 $lang['nosecedit']             = 'Sivu on muuttunut välillä ja kappaleen tiedot olivat vanhentuneet. Koko sivu ladattu.';
@@ -77,23 +81,72 @@ $lang['profna']                = 'Tässä wikissä profiilien muokkaaminen ei ol
 $lang['profnochange']          = 'Ei muutoksia.';
 $lang['profnoempty']           = 'Tyhjä nimi tai sähköpostiosoite ei ole sallittu.';
 $lang['profchanged']           = 'Käyttäjän profiilin päivitys onnistui.';
+$lang['profnodelete']          = 'Tässä wikissä ei voi poistaa käyttäjiä';
+$lang['profdeleteuser']        = 'Poista tili';
+$lang['profdeleted']           = 'Käyttäjätilisi on postettu tästä wikistä';
+$lang['profconfdelete']        = 'Haluan poistaa käyttäjätilini tästä wikistä. <br/> Tätä toimintoa ei voi myöhemmin peruuttaa.';
+$lang['profconfdeletemissing'] = 'Vahvistus rastia ei valittu';
 $lang['pwdforget']             = 'Unohtuiko salasana? Hanki uusi';
 $lang['resendna']              = 'Tämä wiki ei tue salasanan uudelleenlähettämistä.';
-$lang['resendpwd']             = 'Lähetä uusi salasana käyttäjälle';
+$lang['resendpwd']             = 'Aseta uusisalasana';
 $lang['resendpwdmissing']      = 'Kaikki kentät on täytettävä.';
 $lang['resendpwdnouser']       = 'Käyttäjää ei löydy tietokannastamme.';
 $lang['resendpwdbadauth']      = 'Tunnistuskoodi on virheellinen. Varmista, että käytit koko varmistuslinkkiä.';
 $lang['resendpwdconfirm']      = 'Varmistuslinkki on lähetetty sähköpostilla';
 $lang['resendpwdsuccess']      = 'Uusi salasanasi on lähetetty sähköpostilla.';
 $lang['license']               = 'Jollei muuta ole mainittu, niin sisältö tässä wikissä on lisensoitu seuraavalla lisenssillä:';
-$lang['licenseok']             = 'Huom: Muokkaamalla tätä sivua suostut lisensoimaan sisällön seuraavan lisenssin alla:';
+$lang['licenseok']             = 'Huom: Muokkaamalla tätä sivua suostut lisensoimaan sisällön seuraavan lisenssin mukaisesti:';
+$lang['searchmedia']           = 'Etsi tiedostoa nimeltä:';
+$lang['searchmedia_in']        = 'Etsi kohteesta %s';
 $lang['txt_upload']            = 'Valitse tiedosto lähetettäväksi';
 $lang['txt_filename']          = 'Lähetä nimellä (valinnainen)';
 $lang['txt_overwrt']           = 'Ylikirjoita olemassa oleva';
+$lang['maxuploadsize']         = 'Palvelimelle siirto max. %s / tiedosto.';
 $lang['lockedby']              = 'Tällä hetkellä tiedoston on lukinnut';
 $lang['lockexpire']            = 'Lukitus päättyy';
-$lang['willexpire']            = 'Lukituksesi tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';
-$lang['notsavedyet']           = 'Dokumentissa on tallentamattomia muutoksia, jotka häviävät.\n Haluatko varmasti jatkaa?';
+$lang['js']['willexpire']      = 'Lukituksesi tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';
+$lang['js']['notsavedyet']     = 'Dokumentissa on tallentamattomia muutoksia, jotka häviävät.
+ Haluatko varmasti jatkaa?';
+$lang['js']['searchmedia']     = 'Etsi tiedostoja';
+$lang['js']['keepopen']        = 'Pidä valinnan ikkuna avoinna.';
+$lang['js']['hidedetails']     = 'Piilota yksityiskohdat';
+$lang['js']['mediatitle']      = 'Linkkien asetukset';
+$lang['js']['mediadisplay']    = 'Linkin tyyppi';
+$lang['js']['mediaalign']      = 'Tasaus';
+$lang['js']['mediasize']       = 'Kuvan koko';
+$lang['js']['mediatarget']     = 'Linkin kohde';
+$lang['js']['mediaclose']      = 'Sulje';
+$lang['js']['mediainsert']     = 'Liitä';
+$lang['js']['mediadisplayimg'] = 'Näytä kuva.';
+$lang['js']['mediadisplaylnk'] = 'Näytä vain linkki';
+$lang['js']['mediasmall']      = 'Pieni versio';
+$lang['js']['mediamedium']     = 'Keskikokoinen versio';
+$lang['js']['medialarge']      = 'Iso versio';
+$lang['js']['mediaoriginal']   = 'Alkuperäinen versio';
+$lang['js']['medialnk']        = 'Linkki tietosivuun';
+$lang['js']['mediadirect']     = 'Suora linkki alkuperäiseen';
+$lang['js']['medianolnk']      = 'Ei linkkiä';
+$lang['js']['medianolink']     = 'Älä linkitä kuvaa';
+$lang['js']['medialeft']       = 'Tasaa kuva vasemmalle.';
+$lang['js']['mediaright']      = 'Tasaa kuva oikealle.';
+$lang['js']['mediacenter']     = 'Tasaa kuva keskelle.';
+$lang['js']['medianoalign']    = 'Älä tasaa.';
+$lang['js']['nosmblinks']      = 'Linkit Windows-jakoihin toimivat vain Microsoft Internet Explorerilla.
+Voit silti kopioida ja liittää linkin.';
+$lang['js']['linkwiz']         = 'Linkkivelho';
+$lang['js']['linkto']          = 'Linkki kohteeseen:';
+$lang['js']['del_confirm']     = 'Haluatko todella poistaa valitut kohteet?';
+$lang['js']['restore_confirm'] = 'Haluatko varmasti palauttaa tämän version?';
+$lang['js']['media_diff']      = 'Näytä erot:';
+$lang['js']['media_diff_both'] = 'Vierekkäin';
+$lang['js']['media_diff_opacity'] = 'Päällä';
+$lang['js']['media_diff_portions'] = 'Liukusäädin';
+$lang['js']['media_select']    = 'Valitse tiedostot...';
+$lang['js']['media_upload_btn'] = 'Lähetä';
+$lang['js']['media_done_btn']  = 'Valmis';
+$lang['js']['media_drop']      = 'Pudota lähetettävät tiedostot tähän';
+$lang['js']['media_cancel']    = 'Poista';
+$lang['js']['media_overwrt']   = 'Ylikirjoita olemassa olevat tiedostot';
 $lang['rssfailed']             = 'Virhe tapahtui noudettaessa tätä syötettä: ';
 $lang['nothingfound']          = 'Mitään ei löytynyt.';
 $lang['mediaselect']           = 'Mediatiedoston valinta';
@@ -111,11 +164,7 @@ $lang['deletefail']            = 'Kohdetta "%s" poistaminen ei onnistunut - tark
 $lang['mediainuse']            = 'Tiedostoa "%s" ei ole poistettu - se on vielä käytössä.';
 $lang['namespaces']            = 'Nimiavaruudet';
 $lang['mediafiles']            = 'Tarjolla olevat tiedostot';
-$lang['js']['keepopen']        = 'Pidä valinnan ikkuna avoinna.';
-$lang['js']['hidedetails']     = 'Piilota yksityiskohdat';
-$lang['js']['nosmblinks']      = 'Linkit Windows-jakoihin toimivat vain Microsoft Internet Explorerilla.
-Voit silti kopioida ja liittää linkin.';
-$lang['js']['mu_btn']          = 'Lähetä useampia tiedostoja kerralla';
+$lang['accessdenied']          = 'Sinulla ei ole oikeuksia tämän sivun katsomiseen';
 $lang['mediausage']            = 'Käytä seuraavaa merkintätapaa viittausta tehtäessä:';
 $lang['mediaview']             = 'Katsele alkuperäistä tiedostoa';
 $lang['mediaroot']             = 'root';
@@ -131,6 +180,10 @@ $lang['current']               = 'nykyinen';
 $lang['yours']                 = 'Sinun versiosi';
 $lang['diff']                  = 'Näytä eroavaisuudet nykyiseen versioon';
 $lang['diff2']                 = 'Näytä eroavaisuudet valittuun versioon';
+$lang['difflink']              = 'Linkki vertailunäkymään';
+$lang['diff_type']             = 'Näytä eroavaisuudet:';
+$lang['diff_inline']           = 'Sisäkkäin';
+$lang['diff_side']             = 'Vierekkäin';
 $lang['line']                  = 'Rivi';
 $lang['breadcrumb']            = 'Jäljet';
 $lang['youarehere']            = 'Olet täällä';
@@ -138,15 +191,26 @@ $lang['lastmod']               = 'Viimeksi muutettu';
 $lang['by']                    = '/';
 $lang['deleted']               = 'poistettu';
 $lang['created']               = 'luotu';
-$lang['restored']              = 'vanha versio palautettu';
+$lang['restored']              = 'vanha versio palautettu (%s)';
 $lang['external_edit']         = 'ulkoinen muokkaus';
 $lang['summary']               = 'Yhteenveto muokkauksesta';
-$lang['noflash']               = 'Tarvitset <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash pluginnin</a> nähdäksesi tämän sisällön.';
+$lang['noflash']               = 'Tarvitset <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash-liitännäisen</a> nähdäksesi tämän sisällön.';
+$lang['download']              = 'Lataa palanen';
+$lang['tools']                 = 'Työkalut';
+$lang['user_tools']            = 'Käyttäjän työkalut';
+$lang['site_tools']            = 'Sivuston työkalut';
+$lang['page_tools']            = 'Sivutyökalut';
+$lang['skip_to_content']       = 'Siirry sisältöön';
+$lang['sidebar']               = 'Sivupalkki';
 $lang['mail_newpage']          = 'sivu lisätty:';
 $lang['mail_changed']          = 'sivu muutettu:';
+$lang['mail_subscribe_list']   = 'muuttuneet sivut nimiavaruudessa:';
 $lang['mail_new_user']         = 'uusi käyttäjä:';
 $lang['mail_upload']           = 'tiedosto lähetetty:';
-$lang['qb_alert']              = 'Syötä teksti jonka haluat muotoilla.\nSe lisätään dokumentin loppuun.';
+$lang['changes_type']          = 'Näytä muutokset:';
+$lang['pages_changes']         = 'Sivut';
+$lang['media_changes']         = 'Mediatiedostot';
+$lang['both_changes']          = 'Sivut ja mediatiedostot';
 $lang['qb_bold']               = 'Lihavoitu teksti';
 $lang['qb_italic']             = 'Kursivoitu teksti';
 $lang['qb_underl']             = 'Alleviivattu teksti';
@@ -157,6 +221,11 @@ $lang['qb_h2']                 = 'Taso 2 otsikko';
 $lang['qb_h3']                 = 'Taso 3 otsikko';
 $lang['qb_h4']                 = 'Taso 4 otsikko';
 $lang['qb_h5']                 = 'Taso 5 otsikko';
+$lang['qb_h']                  = 'Otsikko';
+$lang['qb_hs']                 = 'Valitse otsikko';
+$lang['qb_hplus']              = 'Ylempi otsikko';
+$lang['qb_hminus']             = 'Alempi otsikko';
+$lang['qb_hequal']             = 'Saman tason otsikko';
 $lang['qb_link']               = 'Sisäinen linkki';
 $lang['qb_extlink']            = 'Ulkoinen linkki';
 $lang['qb_hr']                 = 'Vaakaerotin';
@@ -166,12 +235,12 @@ $lang['qb_media']              = 'Lisää kuvia ja muita tiedostoja';
 $lang['qb_sig']                = 'Lisää allekirjoitus';
 $lang['qb_smileys']            = 'Hymiöt';
 $lang['qb_chars']              = 'Erikoismerkit';
-$lang['del_confirm']           = 'Haluatko todella poistaa valitut kohteet?';
+$lang['upperns']               = 'Hyppää edelliseen nimiavaruuteen';
 $lang['admin_register']        = 'Lisää uusi käyttäjä';
 $lang['metaedit']              = 'Muokkaa metadataa';
 $lang['metasaveerr']           = 'Metadatan kirjoittaminen epäonnistui';
 $lang['metasaveok']            = 'Metadata tallennettu';
-$lang['img_backto']            = 'Takaisin';
+$lang['btn_img_backto']            = 'Takaisin %s';
 $lang['img_title']             = 'Otsikko';
 $lang['img_caption']           = 'Kuvateksti';
 $lang['img_date']              = 'Päivämäärä';
@@ -182,45 +251,86 @@ $lang['img_copyr']             = 'Tekijänoikeus';
 $lang['img_format']            = 'Formaatti';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Avainsanat';
-$lang['subscribe_success']     = '%s lisättiin käyttäjän %s seurattavien listaan';
-$lang['subscribe_error']       = 'Lisättäessä %s käyttäjän %s seurattavien listaan tapahtui virhe';
-$lang['subscribe_noaddress']   = 'Käyttäjänimelle ei löydy osoitetta. Seurattavien listaan lisääminen ei onnistu.';
-$lang['unsubscribe_success']   = '%s poistettiin käyttäjän %s seurattavien listasta';
-$lang['unsubscribe_error']     = 'Poistettaessa %s käyttäjän %s seurattavien listasta tapahtui virhe';
-$lang['authmodfailed']         = 'Käyttäjien autentikoinnin asetukset ovat virheelliset. Ilmoita asiasta wikin ylläpitäjälle.';
+$lang['img_width']             = 'Leveys';
+$lang['img_height']            = 'Korkeus';
+$lang['btn_mediaManager']           = 'Näytä mediamanagerissa';
+$lang['subscr_subscribe_success'] = '%s lisätty %s tilauslistalle';
+$lang['subscr_subscribe_error'] = 'Virhe lisättäessä %s tilauslistalle %s';
+$lang['subscr_subscribe_noaddress'] = 'Login tiedoissasi ei ole sähköpostiosoitetta. Sinua ei voi lisätä tilaukseen';
+$lang['subscr_unsubscribe_success'] = '%s poistettu tilauslistalta %s';
+$lang['subscr_unsubscribe_error'] = 'Virhe tapahtui poistaessa %s tilauslistalta %s';
+$lang['subscr_already_subscribed'] = '%s on jo tilannut %s';
+$lang['subscr_not_subscribed'] = '%s ei ole tilannut %s';
+$lang['subscr_m_not_subscribed'] = 'Et ole tilannut sivua tai nimiavaruutta';
+$lang['subscr_m_new_header']   = 'Lisää tilaus';
+$lang['subscr_m_current_header'] = 'Voimassaolevat tilaukset';
+$lang['subscr_m_unsubscribe']  = 'Poista tilaus';
+$lang['subscr_m_subscribe']    = 'Tilaa';
+$lang['subscr_m_receive']      = 'Vastaanota';
+$lang['subscr_style_every']    = 'Sähköposti joka muutoksesta';
+$lang['subscr_style_digest']   = 'yhteenveto-sähköposti joka sivusta (joka %.2f. päivä)';
+$lang['subscr_style_list']     = 'lista muuttuneista sivuista edellisen sähköpostin jälkeen (joka %.2f. päivä)';
 $lang['authtempfail']          = 'Käyttäjien autentikointi ei tällä hetkellä onnistu. Jos ongelma jatkuu, ota yhteyttä wikin ylläpitäjään.';
+$lang['authpwdexpire']         = 'Salasanasi vanhenee %d pv:n päästä, vaihda salasanasi pikaisesti.';
 $lang['i_chooselang']          = 'Valitse kieli';
 $lang['i_installer']           = 'DokuWikin asentaja';
 $lang['i_wikiname']            = 'Wikin nimi';
 $lang['i_enableacl']           = 'Käytä käyttöoikeuksien hallintaa (ACL) (Suositeltu)';
 $lang['i_superuser']           = 'Pääkäyttäjä';
 $lang['i_problems']            = 'Asennusohjelma löysi alla listattuja ongelmia ongelmia. Et voi jatkaa ennen kuin ne on korjattu.';
-$lang['i_modified']            = 'Turvallisuussyistä tämä ohjelma toimii vain uusien ja muokkaamattoman Dokuwiki asennusten kanssa. Pura tiedostot uudestaan asennuspaketista, tai lue <a href="http://dokuwiki.org/install">Dokuwiki asennusohjeen (Englanniksi)</a>';
-$lang['i_funcna']              = 'PHP funktio <code>%s</code> ei ole käytettävissä. Ehkä palveluntarjoajasi on poistanut sen jostain syystä?';
-$lang['i_phpver']              = 'PHP versiosi <code>%s</code> on pienempi, kuin tarvitaan <code>%s</code>. PHP asennukseni pitää päivittää.';
+$lang['i_modified']            = 'Turvallisuussyistä tämä ohjelma toimii vain uusien ja muokkaamattomien Dokuwiki-asennusten kanssa. Pura tiedostot uudestaan asennuspaketista, tai lue <a href="http://dokuwiki.org/install">Dokuwikin asennusohje (englanniksi)</a>';
+$lang['i_funcna']              = 'PHP:n funktio <code>%s</code> ei ole käytettävissä. Palveluntarjoajasi on saattanut poistaa sen jostain syystä.';
+$lang['i_phpver']              = 'Käyttämäsi PHP-ohjelmiston versio <code>%s</code> on pienempi, kuin tarvitaan <code>%s</code>. PHP-asennuksesi pitää päivittää.';
 $lang['i_permfail']            = '<code>%s</code> ei ole DokuWikin kirjoitettavissa. Muokkaa hakemiston oikeuksia!';
 $lang['i_confexists']          = '<code>%s</code> on jo olemassa';
 $lang['i_writeerr']            = '<code>%s</code>n luonti epäonnistui. Tarkista hakemiston/tiedoston oikeudet ja luo tiedosto käsin.';
 $lang['i_badhash']             = 'tunnistamaton tai muokattu dokuwiki.php (tarkistussumma=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - väärä tai tyhjä arvo';
-$lang['i_success']             = 'Kokoonpano tehty onnistuneesti. Voit poistaa install.php tiedoston. Jatka <a href="doku.php">uuteen DokuWikiisi</a>.';
-$lang['i_failure']             = 'Joitain virheitä tapahtui kirjoitettaessa vaadittavia tiedostoja. Sinun pitää korjata ne käsin ennen kuin voit käyttää <a href="doku.php">uutta DokuWikiäsi</a>.';
-$lang['i_policy']              = 'Käyttöoikeuksien oletus menettelytapa';
-$lang['i_pol0']                = 'Avoin Wiki (luku, kirjoitus, tiedostojen lähetys kaikille)';
+$lang['i_success']             = 'Kokoonpano tehty onnistuneesti. Voit poistaa install.php tiedoston. Jatka <a href="doku.php?id=wiki:welcome">uuteen DokuWikiisi</a>.';
+$lang['i_failure']             = 'Joitain virheitä tapahtui kirjoitettaessa vaadittavia tiedostoja. Sinun pitää korjata ne käsin ennen kuin voit käyttää <a href="doku.php?id=wiki:welcome">uutta DokuWikiäsi</a>.';
+$lang['i_policy']              = 'Käyttöoikeuksien oletusmenettelytapa';
+$lang['i_pol0']                = 'Avoin Wiki (luku, kirjoitus, tiedostojen lähetys on sallittu kaikille)';
 $lang['i_pol1']                = 'Julkinen Wiki (luku kaikilla, kirjoitus ja tiedostojen lähetys rekisteröidyillä käyttäjillä)';
 $lang['i_pol2']                = 'Suljettu Wiki (luku, kirjoitus ja tiedostojen lähetys vain rekisteröityneillä käyttäjillä)';
+$lang['i_allowreg']            = 'Salli käyttäjien rekisteröityminen';
 $lang['i_retry']               = 'Yritä uudelleen';
-$lang['mu_intro']              = 'Täällä voit lähettää useampia tiedostoja kerralla. Klikkaa Selaa-nappia lisätäksesi ne jonoon. Paina lähetä, kun olet valmis.';
-$lang['mu_gridname']           = 'Tiedoston nimi';
-$lang['mu_gridsize']           = 'Koko';
-$lang['mu_gridstat']           = 'Tilanne';
-$lang['mu_namespace']          = 'Nimiavaruus';
-$lang['mu_browse']             = 'Selaa';
-$lang['mu_toobig']             = 'liian iso';
-$lang['mu_ready']              = 'valmis lähetettäväksi';
-$lang['mu_done']               = 'valmis';
-$lang['mu_fail']               = 'epäonnistui';
-$lang['mu_authfail']           = 'istunto on vanhentunut';
-$lang['mu_progress']           = '@PCT@% lähetetty';
-$lang['mu_filetypes']          = 'Sallitut tyypit';
+$lang['i_license']             = 'Valitse lisenssi, jonka alle haluat sisältösi laittaa:';
+$lang['i_license_none']        = 'Älä näytä mitään lisenssitietoja';
+$lang['i_pop_field']           = 'Auta parantamaan DokuWikiä';
+$lang['i_pop_label']           = 'Lähetä kerran kuussa nimetöntä käyttäjätietoa DokuWikin kehittäjille';
 $lang['recent_global']         = 'Seuraat tällä hetkellä muutoksia nimiavaruuden <b>%s</b> sisällä. Voit myös <a href="%s">katsoa muutoksia koko wikissä</a>';
+$lang['years']                 = '%d vuotta sitten';
+$lang['months']                = '%d kuukautta sitten';
+$lang['weeks']                 = '%d viikkoa sitten';
+$lang['days']                  = '%d päivää sitten';
+$lang['hours']                 = '%d tuntia sitten';
+$lang['minutes']               = '%d minuuttia sitten';
+$lang['seconds']               = '%d sekuntia sitten';
+$lang['wordblock']             = 'Muutostasi ei talletettu, koska se sisältää estettyä tekstiä (spam).';
+$lang['media_uploadtab']       = 'Lähetä';
+$lang['media_searchtab']       = 'Etsi';
+$lang['media_file']            = 'Tiedosto';
+$lang['media_viewtab']         = 'Näytä';
+$lang['media_edittab']         = 'Muokkaa';
+$lang['media_historytab']      = 'Historia';
+$lang['media_list_thumbs']     = 'Thumbnails';
+$lang['media_list_rows']       = 'Rivit';
+$lang['media_sort_name']       = 'nimen mukaan';
+$lang['media_sort_date']       = 'päivämäärän mukaan';
+$lang['media_namespaces']      = 'Valitse nimiavaruus';
+$lang['media_files']           = 'Tiedostoja %s';
+$lang['media_upload']          = 'Lähetä <strong>%s</strong> nimiavaruuteen';
+$lang['media_search']          = 'Etsi <strong>%s</strong> nimiavaruudesta';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s at %s';
+$lang['media_edit']            = 'Muokkaa %s';
+$lang['media_history']         = 'Nämä ovat vanhat versiot tiedostosta %s';
+$lang['media_meta_edited']     = 'Metadataa muokattu';
+$lang['media_perm_read']       = 'Anteeksi. Sinulla ei ole riittävästi oikeuksia lukeaksesi tiedostoja.';
+$lang['media_perm_upload']     = 'Anteeksi. Sinulla ei ole riittävästi oikeuksia lähettääksesi tiedostoja.';
+$lang['media_update']          = 'Lähetä uusi versio';
+$lang['media_restore']         = 'Palauta tämä versio';
+$lang['currentns']             = 'Nykyinen nimiavaruus';
+$lang['searchresult']          = 'Haun tulokset';
+$lang['plainhtml']             = 'pelkkä HTML';
+$lang['wikimarkup']            = 'Wiki markup';
