@@ -157,7 +157,7 @@ $lang['admin_register']        = 'Upprætta nýggjan brúkara';
 $lang['metaedit']              = 'Rætta metadáta';
 $lang['metasaveerr']           = 'Brek við skriving av metadáta';
 $lang['metasaveok']            = 'Metadáta goymt';
-$lang['img_backto']            = 'Aftur til';
+$lang['btn_img_backto']            = 'Aftur til %s';
 $lang['img_title']             = 'Heitið';
 $lang['img_caption']           = 'Myndatekstur';
 $lang['img_date']              = 'Dato';
