@@ -11,6 +11,8 @@
  * @author Yaron Shahrabani <sh.yaron@gmail.com>
  * @author Roy Zahor <roy.zahor@gmail.com>
  * @author alex <ralexay@gmail.com>
+ * @author matt carroll <matt.carroll@gmail.com>
+ * @author tomer <tomercarolldergicz@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'rtl';
@@ -52,7 +54,9 @@ $lang['btn_recover']           = 'שחזור טיוטה';
 $lang['btn_draftdel']          = 'מחיקת טיוטה';
 $lang['btn_revert']            = 'שחזור';
 $lang['btn_register']          = 'הרשמה';
+$lang['btn_apply']             = 'ליישם';
 $lang['btn_media']             = 'מנהל המדיה';
+$lang['btn_deleteuser']        = 'להסיר את החשבון שלי';
 $lang['loggedinas']            = 'נכנסת בשם';
 $lang['user']                  = 'שם משתמש';
 $lang['pass']                  = 'ססמה';
@@ -81,7 +85,11 @@ $lang['profna']                = 'בוויקי הזה לא ניתן לשנות 
 $lang['profnochange']          = 'אין שינויים, הפרופיל לא עודכן';
 $lang['profnoempty']           = 'השם וכתובת הדוא״ל לא יכולים להיות ריקים';
 $lang['profchanged']           = 'הפרופיל עודכן בהצלחה';
+$lang['profnodelete']          = 'ויקי  אינה תומכת במחיקת משתמשים';
 $lang['profdeleteuser']        = 'הסר חשבון';
+$lang['profdeleted']           = 'חשבון המשתמש שלך נמחק מויקי זה';
+$lang['profconfdelete']        = 'ברצוני להסיר את החשבון שלי מוויקי זה. <br/> לא ניתן לבטל פעולה זו.';
+$lang['profconfdeletemissing'] = 'תיבת אישור אינו מסומן';
 $lang['pwdforget']             = 'שכחת את הססמה שלך? ניתן לקבל חדשה';
 $lang['resendna']              = 'הוויקי הזה אינו תומך בחידוש ססמה';
 $lang['resendpwd']             = 'הגדר סיסמא חדשה בעבור';
@@ -97,6 +105,7 @@ $lang['searchmedia_in']        = 'חיפוש תחת %s';
 $lang['txt_upload']            = 'בחירת קובץ להעלות';
 $lang['txt_filename']          = 'העלאה בשם (נתון לבחירה)';
 $lang['txt_overwrt']           = 'שכתוב על קובץ קיים';
+$lang['maxuploadsize']         = 'העלה מקסימום. s% לכל קובץ.';
 $lang['lockedby']              = 'נעול על ידי';
 $lang['lockexpire']            = 'הנעילה פגה';
 $lang['js']['willexpire']      = 'הנעילה תחלוף עוד זמן קצר. \nלמניעת התנגשויות יש להשתמש בכפתור הרענון מטה כדי לאפס את מד משך הנעילה.';
@@ -133,6 +142,8 @@ $lang['js']['del_confirm']     = 'באמת למחוק?';
 $lang['js']['restore_confirm'] = 'באמת לשחזר את הגירסא הזאת?';
 $lang['js']['media_diff']      = 'הצגת הבדלים:';
 $lang['js']['media_diff_both'] = 'זה לצד זה';
+$lang['js']['media_diff_opacity'] = 'ניקוי דרך';
+$lang['js']['media_diff_portions'] = 'לחבוט';
 $lang['js']['media_select']    = 'בחר קבצים...';
 $lang['js']['media_upload_btn'] = 'העלאה';
 $lang['js']['media_done_btn']  = 'בוצע';
@@ -193,13 +204,16 @@ $lang['user_tools']            = 'כלים של משתמש';
 $lang['site_tools']            = 'כלים של אתר';
 $lang['page_tools']            = 'כלים של דף';
 $lang['skip_to_content']       = 'עבור לתוכן';
+$lang['sidebar']               = 'הסרגל הצידי';
 $lang['mail_newpage']          = 'דף נוסף:';
 $lang['mail_changed']          = 'דף שונה:';
 $lang['mail_subscribe_list']   = 'דפים שהשתנו במרחב השם:';
 $lang['mail_new_user']         = 'משתמש חדש:';
 $lang['mail_upload']           = 'קובץ הועלה:';
+$lang['changes_type']          = 'צפו בשינויים של';
 $lang['pages_changes']         = 'דפים';
 $lang['media_changes']         = 'קבצי מדיה';
+$lang['both_changes']          = 'קבצי מדיה ודפים ';
 $lang['qb_bold']               = 'טקסט מודגש';
 $lang['qb_italic']             = 'טקסט נטוי';
 $lang['qb_underl']             = 'טקסט עם קו תחתון';
@@ -229,7 +243,7 @@ $lang['admin_register']        = 'הוספת משתמש חדש';
 $lang['metaedit']              = 'עריכת נתוני העל';
 $lang['metasaveerr']           = 'אירע כשל בשמירת נתוני העל';
 $lang['metasaveok']            = 'נתוני העל נשמרו';
-$lang['img_backto']            = 'חזרה אל';
+$lang['btn_img_backto']            = 'חזרה אל %s';
 $lang['img_title']             = 'שם';
 $lang['img_caption']           = 'כותרת';
 $lang['img_date']              = 'תאריך';
@@ -242,6 +256,7 @@ $lang['img_camera']            = 'מצלמה';
 $lang['img_keywords']          = 'מילות מפתח';
 $lang['img_width']             = 'רוחב';
 $lang['img_height']            = 'גובה';
+$lang['btn_mediaManager']           = 'צפה במנהל מדיה';
 $lang['subscr_subscribe_success'] = '%s נוסף לרשימת המינויים לדף %s';
 $lang['subscr_subscribe_error'] = 'אירעה שגיאה בהוספת %s לרשימת המינויים לדף %s';
 $lang['subscr_subscribe_noaddress'] = 'אין כתובת המשויכת עם הכניסה שלך, נא ניתן להוסיף אותך לרשימת המינויים';
@@ -259,6 +274,7 @@ $lang['subscr_style_every']    = 'דוא״ל עם כל שינוי';
 $lang['subscr_style_digest']   = 'הודעת דוא״ל המציגה את כל השינויים בכל עמוד (בכל %.2f ימים)';
 $lang['subscr_style_list']     = 'רשימת השינויים בדפים מאז הודעת הדוא״ל האחרונה (בכל %.2f ימים)';
 $lang['authtempfail']          = 'אימות משתמשים אינו זמין כרגע. אם מצב זה נמשך נא ליידע את מנהל הוויקי.';
+$lang['authpwdexpire']         = 'הסיסמה שלך תפוג ב% d ימים, אתה צריך לשנות את זה בקרוב.';
 $lang['i_chooselang']          = 'נא לבחור שפה';
 $lang['i_installer']           = 'תכנית ההתקנה של DokuWiki';
 $lang['i_wikiname']            = 'שם הוויקי';
@@ -269,6 +285,7 @@ $lang['i_modified']            = 'משיקולי אבטחה סקריפט זה י
                          עליך לחלץ שנית את הקבצים מהחבילה שהורדה או להיעזר בדף
                          <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a>';
 $lang['i_funcna']              = 'פונקציית ה-PHP&rlm; <code>%s</code> אינה זמינה. יתכן כי מארח האתר חסם אותה מסיבה כלשהי?';
+$lang['i_phpver']              = 'גרסת PHP שלך <code>%s</code> נמוכה מ <code>%s</code> הצורך. אתה צריך לשדרג PHP שלך להתקין.';
 $lang['i_permfail']            = '<code>%s</code> אינה ניתנת לכתיבה על ידי DokuWiki. עליך לשנות הרשאות תיקייה זו!';
 $lang['i_confexists']          = '<code>%s</code> כבר קיים';
 $lang['i_writeerr']            = 'אין אפשרות ליצור את <code>%s</code>. נא לבדוק את הרשאות הקובץ/תיקייה וליצור את הקובץ ידנית.';
@@ -280,8 +297,12 @@ $lang['i_policy']              = 'מדיניות ACL התחלתית';
 $lang['i_pol0']                = 'ויקי פתוח (קריאה, כתיבה והעלאה לכולם)';
 $lang['i_pol1']                = ' ויקי ציבורי (קריאה לכולם, כתיבה והעלאה למשתמשים רשומים)';
 $lang['i_pol2']                = 'ויקי סגור (קריאה, כתיבה והעלאה למשתמשים רשומים בלבד)';
+$lang['i_allowreg']            = 'אפשר למשתמשים לרשום את עצמם';
 $lang['i_retry']               = 'ניסיון נוסף';
 $lang['i_license']             = 'נא לבחור את הרישיון שיחול על התוכן שבוויקי שלך:';
+$lang['i_license_none']        = 'אל תציג כל מידע רישיון';
+$lang['i_pop_field']           = 'אנא, עזרו לנו לשפר את חווית ה DokuWiki:';
+$lang['i_pop_label']           = 'פעם בחודש, לשלוח את נתוני שימוש אנונימיים למפתחי DokuWiki';
 $lang['recent_global']         = 'נכון לעכשיו מתנהל על ידיך מעקב אחר מרחב השם <b>%s</b>. כמו כן, באפשרותך <a href="%s">לצפות בשינויים האחרונים בוויקי כולו</a>.';
 $lang['years']                 = 'לפני %d שנים';
 $lang['months']                = 'לפני %d חודשים';
@@ -291,12 +312,16 @@ $lang['hours']                 = 'לפני %d שעות';
 $lang['minutes']               = 'לפני %d דקות';
 $lang['seconds']               = 'לפני %d שניות';
 $lang['wordblock']             = 'השינויים שלך לא נשמרו כיוון שהם מכילים טקסט חסום (ספאם).';
+$lang['media_uploadtab']       = 'להעלות';
 $lang['media_searchtab']       = 'חיפוש';
 $lang['media_file']            = 'קובץ';
 $lang['media_viewtab']         = 'תצוגה';
 $lang['media_edittab']         = 'עריכה';
 $lang['media_historytab']      = 'היסטוריה';
+$lang['media_list_thumbs']     = 'תמונות ממוזערות';
 $lang['media_list_rows']       = 'שורות';
 $lang['media_sort_name']       = 'שם';
 $lang['media_sort_date']       = 'תאריך';
 $lang['media_namespaces']      = 'בחר מרחב שמות';
+$lang['media_files']           = 'קבצים ב s%';
+$lang['media_upload']          = 'להעלות s%';
