@@ -103,7 +103,7 @@ $lang['qb_extlink']            = 'बाह्य कड़ी';
 $lang['qb_hr']                 = 'खड़ी रेखा';
 $lang['qb_sig']                = 'हस्ताक्षर डालें';
 $lang['admin_register']        = 'नया उपयोगकर्ता जोड़ें';
-$lang['img_backto']            = 'वापस जाना';
+$lang['btn_img_backto']            = 'वापस जाना %s';
 $lang['img_title']             = 'शीर्षक';
 $lang['img_caption']           = 'सहशीर्षक';
 $lang['img_date']              = 'तिथि';
