@@ -204,7 +204,7 @@ $lang['admin_register']        = 'Dodaj novog korisnika';
 $lang['metaedit']              = 'Uredi metapodatake';
 $lang['metasaveerr']           = 'Neuspješno zapisivanje metapodataka';
 $lang['metasaveok']            = 'Spremljeni metapdaci';
-$lang['img_backto']            = 'Povratak na';
+$lang['btn_img_backto']            = 'Povratak na %s';
 $lang['img_title']             = 'Naziv';
 $lang['img_caption']           = 'Naslov';
 $lang['img_date']              = 'Datum';
