@@ -202,7 +202,7 @@ $lang['admin_register']        = 'Adder nove usator';
 $lang['metaedit']              = 'Modificar metadatos';
 $lang['metasaveerr']           = 'Scriptura de metadatos fallite';
 $lang['metasaveok']            = 'Metadatos salveguardate';
-$lang['img_backto']            = 'Retornar a';
+$lang['btn_img_backto']            = 'Retornar a %s';
 $lang['img_title']             = 'Titulo';
 $lang['img_caption']           = 'Legenda';
 $lang['img_date']              = 'Data';
