@@ -170,7 +170,7 @@ $lang['admin_register']        = 'Setja nýjan notenda inn';
 $lang['metaedit']              = 'Breyta lýsigögnum';
 $lang['metasaveerr']           = 'Vistun lýsigagna mistókst';
 $lang['metasaveok']            = 'Lýsigögn vistuð';
-$lang['img_backto']            = 'Aftur til';
+$lang['btn_img_backto']            = 'Aftur til %s';
 $lang['img_title']             = 'Heiti';
 $lang['img_caption']           = 'Skýringartexti';
 $lang['img_date']              = 'Dagsetning';
