@@ -240,7 +240,7 @@ $lang['admin_register']        = '新規ユーザー作成';
 $lang['metaedit']              = 'メタデータ編集';
 $lang['metasaveerr']           = 'メタデータの書き込みに失敗しました';
 $lang['metasaveok']            = 'メタデータは保存されました';
-$lang['img_backto']            = '戻る';
+$lang['btn_img_backto']            = '戻る %s';
 $lang['img_title']             = 'タイトル';
 $lang['img_caption']           = '見出し';
 $lang['img_date']              = '日付';
@@ -253,7 +253,7 @@ $lang['img_camera']            = '使用カメラ';
 $lang['img_keywords']          = 'キーワード';
 $lang['img_width']             = '幅';
 $lang['img_height']            = '高さ';
-$lang['img_manager']           = 'メディアマネージャーで閲覧';
+$lang['btn_mediaManager']           = 'メディアマネージャーで閲覧';
 $lang['subscr_subscribe_success'] = '%sが%sの購読リストに登録されました。';
 $lang['subscr_subscribe_error'] = '%sを%sの購読リストへの追加に失敗しました。';
 $lang['subscr_subscribe_noaddress'] = 'あなたのログインに対応するアドレスがないため、購読リストへ追加することができません。';
