@@ -127,7 +127,7 @@ $lang['admin_register']= 'Add new user...';
 $lang['metaedit']    = 'Edit Metadata';
 $lang['metasaveerr'] = 'Writing metadata failed';
 $lang['metasaveok']  = 'Metadata saved';
-$lang['img_backto']  = 'Back to';
+$lang['btn_img_backto']  = 'Back to %s';
 $lang['img_title']   = 'Title';
 $lang['img_caption'] = 'Caption';
 $lang['img_date']    = 'Date';
