@@ -202,7 +202,7 @@ $lang['admin_register']        = 'Nouom Sodalem creare';
 $lang['metaedit']              = 'Res codicis mutare';
 $lang['metasaveerr']           = 'Res codicis non scribitur.';
 $lang['metasaveok']            = 'Res codicis seruatae.';
-$lang['img_backto']            = 'Redere ad';
+$lang['btn_img_backto']            = 'Redere ad %s';
 $lang['img_title']             = 'Titulus';
 $lang['img_caption']           = 'Descriptio';
 $lang['img_date']              = 'Dies';
