@@ -162,7 +162,7 @@ $lang['admin_register']        = 'Neie Benotzer bäisetzen';
 $lang['metaedit']              = 'Metadaten änneren';
 $lang['metasaveerr']           = 'Feeler beim Schreiwe vun de Metadaten';
 $lang['metasaveok']            = 'Metadate gespäichert';
-$lang['img_backto']            = 'Zeréck op';
+$lang['btn_img_backto']            = 'Zeréck op %s';
 $lang['img_title']             = 'Titel';
 $lang['img_caption']           = 'Beschreiwung';
 $lang['img_date']              = 'Datum';
