@@ -163,7 +163,7 @@ $lang['admin_register']        = 'Sukurti naują vartotoją';
 $lang['metaedit']              = 'Redaguoti metaduomenis';
 $lang['metasaveerr']           = 'Nepavyko išsaugoti metaduomenų';
 $lang['metasaveok']            = 'Metaduomenys išsaugoti';
-$lang['img_backto']            = 'Atgal į';
+$lang['btn_img_backto']            = 'Atgal į %s';
 $lang['img_title']             = 'Pavadinimas';
 $lang['img_caption']           = 'Antraštė';
 $lang['img_date']              = 'Data';
