@@ -228,7 +228,7 @@ $lang['admin_register']        = 'Pievienot jaunu lietotāju';
 $lang['metaedit']              = 'Labot metadatus';
 $lang['metasaveerr']           = 'Metadati nav saglabāti';
 $lang['metasaveok']            = 'Metadati saglabāti';
-$lang['img_backto']            = 'Atpakaļ uz';
+$lang['btn_img_backto']            = 'Atpakaļ uz %s';
 $lang['img_title']             = 'Virsraksts';
 $lang['img_caption']           = 'Apraksts';
 $lang['img_date']              = 'Datums';
@@ -241,7 +241,7 @@ $lang['img_camera']            = 'Fotoaparāts';
 $lang['img_keywords']          = 'Atslēgvārdi';
 $lang['img_width']             = 'Platums';
 $lang['img_height']            = 'Augstums';
-$lang['img_manager']           = 'Skatīt mēdiju pārvaldniekā';
+$lang['btn_mediaManager']           = 'Skatīt mēdiju pārvaldniekā';
 $lang['subscr_subscribe_success'] = '%s pievienots %s abonēšanas sarakstam';
 $lang['subscr_subscribe_error'] = 'Kļūme pievienojot %s %s abonēšanas sarakstam.';
 $lang['subscr_subscribe_noaddress'] = 'Nav zināma jūsu e-pasta adrese, tāpēc nevarat abonēt.';
