@@ -171,7 +171,7 @@ $lang['admin_register']        = 'Додај нов корисник';
 $lang['metaedit']              = 'Уреди мета-податоци';
 $lang['metasaveerr']           = 'Запишување на мета-податоците не успеа';
 $lang['metasaveok']            = 'Мета-податоците се зачувани';
-$lang['img_backto']            = 'Назад до';
+$lang['btn_img_backto']            = 'Назад до %s';
 $lang['img_title']             = 'Насловна линија';
 $lang['img_caption']           = 'Наслов';
 $lang['img_date']              = 'Датум';
