@@ -227,7 +227,7 @@ $lang['admin_register']        = 'नवीन सदस्य';
 $lang['metaedit']              = 'मेटाडेटा बदला';
 $lang['metasaveerr']           = 'मेटाडेटा सुरक्षित झाला नाही';
 $lang['metasaveok']            = 'मेटाडेटा सुरक्षित झाला';
-$lang['img_backto']            = 'परत जा';
+$lang['btn_img_backto']            = 'परत जा %s';
 $lang['img_title']             = 'नाव';
 $lang['img_caption']           = 'टीप';
 $lang['img_date']              = 'तारीख';
@@ -240,7 +240,7 @@ $lang['img_camera']            = 'कॅमेरा';
 $lang['img_keywords']          = 'मुख्य शब्द';
 $lang['img_width']             = 'रुंदी';
 $lang['img_height']            = 'उंची';
-$lang['img_manager']           = 'मिडिया व्यवस्थापकात बघू';
+$lang['btn_mediaManager']           = 'मिडिया व्यवस्थापकात बघू';
 $lang['authtempfail']          = 'सदस्य अधिकृत करण्याची सुविधा सध्या चालू नाही. सतत हा मजकूर दिसल्यास कृपया तुमच्या विकीच्या व्यवस्थापकाशी सम्पर्क साधा.';
 $lang['i_chooselang']          = 'तुमची भाषा निवडा';
 $lang['i_installer']           = 'डॉक्युविकि इनस्टॉलर';
