@@ -158,7 +158,7 @@ $lang['admin_register']        = 'नयाँ प्रयोगकर्ता
 $lang['metaedit']              = 'मेटाडेटा सम्पादन गर्नुहोस्';
 $lang['metasaveerr']           = 'मेटाडाटा लेखन असफल';
 $lang['metasaveok']            = 'मेटाडाटा वचत भयो ';
-$lang['img_backto']            = 'फिर्ता';
+$lang['btn_img_backto']            = 'फिर्ता%s';
 $lang['img_title']             = 'शिर्षक';
 $lang['img_caption']           = 'निम्न लेख';
 $lang['img_date']              = 'मिति';
