@@ -233,7 +233,7 @@ $lang['admin_register']        = 'Registar Novo Utilizador';
 $lang['metaedit']              = 'Editar Metadata';
 $lang['metasaveerr']           = 'Falhou a escrita de Metadata';
 $lang['metasaveok']            = 'Metadata gravada';
-$lang['img_backto']            = 'De volta a';
+$lang['btn_img_backto']            = 'De volta a %s';
 $lang['img_title']             = 'Título';
 $lang['img_caption']           = 'Legenda';
 $lang['img_date']              = 'Data';
@@ -246,7 +246,7 @@ $lang['img_camera']            = 'Câmara';
 $lang['img_keywords']          = 'Palavras-Chave';
 $lang['img_width']             = 'Largura';
 $lang['img_height']            = 'Altura';
-$lang['img_manager']           = 'Ver em gestor de media';
+$lang['btn_mediaManager']           = 'Ver em gestor de media';
 $lang['subscr_subscribe_success'] = 'Adicionado %s à lista de subscrição para %s';
 $lang['subscr_subscribe_error'] = 'Erro ao adicionar %s à lista de subscrição para %s';
 $lang['subscr_subscribe_noaddress'] = 'Não existe endereço algum associado com o seu nome de utilizador, não pode ser adicionado à lista de subscrição';
