@@ -23,6 +23,9 @@
  * @author Ivan I. Udovichenko (sendtome@mymailbox.pp.ua)
  * @author Pavel <ivanovtsk@mail.ru>
  * @author Artur <ncuxxx@gmail.com>
+ * @author Erli Moen <evseev.jr@gmail.com>
+ * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
+ * @author Владимир <id37736@yandex.ru>
  */
 $lang['encoding']              = ' utf-8';
 $lang['direction']             = 'ltr';
@@ -67,6 +70,8 @@ $lang['btn_register']          = 'Зарегистрироваться';
 $lang['btn_apply']             = 'Применить';
 $lang['btn_media']             = 'Управление медиафайлами';
 $lang['btn_deleteuser']        = 'Удалить мой аккаунт';
+$lang['btn_img_backto']        = 'Вернуться к %s';
+$lang['btn_mediaManager']      = 'Просмотр в «управлении медиафайлами»';
 $lang['loggedinas']            = 'Зашли как';
 $lang['user']                  = 'Логин';
 $lang['pass']                  = 'Пароль';
@@ -89,7 +94,7 @@ $lang['regsuccess2']           = 'Пользователь создан.';
 $lang['regmailfail']           = 'Похоже есть проблема с отправкой пароля по почте. Пожалуйста, сообщите об этом администратору.';
 $lang['regbadmail']            = 'Данный вами адрес электронной почты выглядит неправильным. Если вы считаете это ошибкой, сообщите администратору.';
 $lang['regbadpass']            = 'Два введённых пароля не идентичны. Пожалуйста, попробуйте ещё раз.';
-$lang['regpwmail']             = 'Ваш пароль для системы «ДокуВики»';
+$lang['regpwmail']             = 'Ваш пароль для системы «Докувики»';
 $lang['reghere']               = 'У вас ещё нет аккаунта? Зарегистрируйтесь';
 $lang['profna']                = 'Данная вики не поддерживает изменение профиля';
 $lang['profnochange']          = 'Изменений не было внесено, профиль не обновлён.';
@@ -144,7 +149,7 @@ $lang['js']['medialeft']       = 'Выровнять изображение по
 $lang['js']['mediaright']      = 'Выровнять изображение по правому краю.';
 $lang['js']['mediacenter']     = 'Выровнять изображение по центру.';
 $lang['js']['medianoalign']    = 'Не выравнивать.';
-$lang['js']['nosmblinks']      = 'Ссылка на сетевые каталоги Windows работает только из Интернет Эксплорера. Но вы можете скопировать ссылку.';
+$lang['js']['nosmblinks']      = 'Ссылка на сетевые каталоги Windows работает только из MS Internet Explorer, но вы можете скопировать ссылку.';
 $lang['js']['linkwiz']         = 'Мастер ссылок';
 $lang['js']['linkto']          = 'Ссылка на:';
 $lang['js']['del_confirm']     = 'Вы на самом деле желаете удалить выбранное?';
@@ -196,6 +201,9 @@ $lang['difflink']              = 'Ссылка на это сравнение';
 $lang['diff_type']             = 'Посмотреть отличия';
 $lang['diff_inline']           = 'встроенный';
 $lang['diff_side']             = 'бок о бок';
+$lang['diffprevrev']           = 'Предыдущая версия';
+$lang['diffnextrev']           = 'Следущая версия';
+$lang['difflastrev']           = 'Последняя версия';
 $lang['line']                  = 'Строка';
 $lang['breadcrumb']            = 'Вы посетили';
 $lang['youarehere']            = 'Вы находитесь здесь';
@@ -252,7 +260,6 @@ $lang['admin_register']        = 'Добавить пользователя';
 $lang['metaedit']              = 'Править метаданные';
 $lang['metasaveerr']           = 'Ошибка записи метаданных';
 $lang['metasaveok']            = 'Метаданные сохранены';
-$lang['img_backto']            = 'Вернуться к';
 $lang['img_title']             = 'Название';
 $lang['img_caption']           = 'Подпись';
 $lang['img_date']              = 'Дата';
@@ -265,7 +272,6 @@ $lang['img_camera']            = 'Модель';
 $lang['img_keywords']          = 'Ключевые слова';
 $lang['img_width']             = 'Ширина';
 $lang['img_height']            = 'Высота';
-$lang['img_manager']           = 'Просмотр в «управлении медиафайлами»';
 $lang['subscr_subscribe_success'] = 'Добавлен %s в подписку на %s';
 $lang['subscr_subscribe_error'] = 'Невозможно добавить %s в подписку на %s';
 $lang['subscr_subscribe_noaddress'] = 'Нет адреса электронной почты, сопоставленного с вашей учётной записью. Вы не можете подписаться на рассылку';
@@ -285,33 +291,34 @@ $lang['subscr_style_list']     = 'список изменённых страни
 $lang['authtempfail']          = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом своему администратору вики.';
 $lang['authpwdexpire']         = 'Действие вашего пароля истекает через %d дней. Вы должны изменить его как можно скорее';
 $lang['i_chooselang']          = 'Выберите свой язык/Choose your language';
-$lang['i_installer']           = 'Установка «ДокуВики»';
+$lang['i_installer']           = 'Установка «Докувики»';
 $lang['i_wikiname']            = 'Название вики';
 $lang['i_enableacl']           = 'Разрешить ограничение прав доступа (рекомендуется)';
 $lang['i_superuser']           = 'Суперпользователь';
 $lang['i_problems']            = 'Программа установки столкнулась с проблемами, перечисленными ниже. Чтобы продолжить, вам необходимо их устранить. ';
-$lang['i_modified']            = 'Из соображений безопасности эта программа запускается только на новой, неизменённой установке «ДокуВики».
+$lang['i_modified']            = 'Из соображений безопасности эта программа запускается только на новой, неизменённой установке «Докувики».
                                   Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
-                                  <a href="http://www.dokuwiki.org/install">инструкции по установке «ДокуВики»</a>';
+                                  <a href="http://www.dokuwiki.org/install">инструкции по установке «Докувики»</a>';
 $lang['i_funcna']              = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована вашим хостером?';
 $lang['i_phpver']              = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
-$lang['i_permfail']            = '<code>%s</code> недоступна для записи «ДокуВики». Вам необходимо исправить системные права доступа для этой директории!';
+$lang['i_permfail']            = '<code>%s</code> недоступна для записи «Докувики». Вам необходимо исправить системные права доступа для этой директории!';
 $lang['i_confexists']          = '<code>%s</code> уже существует';
-$lang['i_writeerr']            = 'Не удалось создать <code>%s</code>. Вам необходимо проверить системные права доступа к файлу/директориям и создать файл вручную. ';
+$lang['i_writeerr']            = 'Не удалось создать <code>%s</code>. Вам необходимо проверить системные права доступа к файлу и директориям, и создать файл вручную. ';
 $lang['i_badhash']             = 'dokuwiki.php не распознан или изменён (хэш=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> — недопустимое или пустое значение';
 $lang['i_success']             = 'Конфигурация прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
-                                 <a href="doku.php?id=wiki:welcome">своей новой «ДокуВики»</a>.';
-$lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php?id=wiki:welcome">свою новую «ДокуВики»</a>.';
+                                 <a href="doku.php?id=wiki:welcome">своей новой «Докувики»</a>.';
+$lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php?id=wiki:welcome">свою новую «Докувики»</a>.';
 $lang['i_policy']              = 'Исходная политика прав доступа';
 $lang['i_pol0']                = 'Открытая вики (чтение, запись, закачка файлов для всех)';
 $lang['i_pol1']                = 'Общедоступная вики (чтение для всех, запись и загрузка файлов для зарегистрированных пользователей)';
 $lang['i_pol2']                = 'Закрытая вики (чтение, запись и загрузка файлов только для зарегистрированных пользователей)';
+$lang['i_allowreg']            = 'Разрешить пользователям самостоятельно регистрироваться';
 $lang['i_retry']               = 'Повторить попытку';
-$lang['i_license']             = 'Пожалуйста, выберите тип лицензии для своей вики:';
-$lang['i_license_none']        = 'Не отображать информацию о лицензионных операциях';
-$lang['i_pop_field']           = 'Пожалуйста, помогите нам улучшить «ДокуВики»:';
-$lang['i_pop_label']           = 'Отправлять раз в месяц анонимную пользовательскую информацию разработчикам «ДокуВики»';
+$lang['i_license']             = 'Пожалуйста, выберите тип лицензии для своей вики';
+$lang['i_license_none']        = 'Не отображать информацию о лицензии';
+$lang['i_pop_field']           = 'Пожалуйста, помогите нам улучшить «Докувики»:';
+$lang['i_pop_label']           = 'Отправлять раз в месяц анонимную пользовательскую информацию разработчикам «Докувики»';
 $lang['recent_global']         = 'Вы просматриваете изменения в пространстве имён <b>%s</b>. Вы можете также <a href="%s">просмотреть недавние изменения во всей вики</a>.';
 $lang['years']                 = '%d лет назад';
 $lang['months']                = '%d месяц(ев) назад';
@@ -345,3 +352,7 @@ $lang['media_perm_read']       = 'Извините, у вас недостато
 $lang['media_perm_upload']     = 'Извините, у вас недостаточно прав для загрузки файлов.';
 $lang['media_update']          = 'Загрузить новую версию';
 $lang['media_restore']         = 'Восстановить эту версию';
+$lang['currentns']             = 'Текущее пространство имён';
+$lang['searchresult']          = 'Результаты поиска';
+$lang['plainhtml']             = 'Простой HTML';
+$lang['wikimarkup']            = 'вики-разметка';
