@@ -238,7 +238,7 @@ $lang['admin_register']        = 'Pridaj nového užívateľa';
 $lang['metaedit']              = 'Upraviť metainformácie';
 $lang['metasaveerr']           = 'Zápis metainformácií zlyhal';
 $lang['metasaveok']            = 'Metainformácie uložené';
-$lang['img_backto']            = 'Späť na';
+$lang['btn_img_backto']            = 'Späť na %s';
 $lang['img_title']             = 'Titul';
 $lang['img_caption']           = 'Popis';
 $lang['img_date']              = 'Dátum';
@@ -251,7 +251,7 @@ $lang['img_camera']            = 'Fotoaparát';
 $lang['img_keywords']          = 'Kľúčové slová';
 $lang['img_width']             = 'Šírka';
 $lang['img_height']            = 'Výška';
-$lang['img_manager']           = 'Prezrieť v správcovi médií';
+$lang['btn_mediaManager']           = 'Prezrieť v správcovi médií';
 $lang['subscr_subscribe_success'] = 'Používateľ %s bol pridaný do zoznamu hlásení o zmenách %s';
 $lang['subscr_subscribe_error'] = 'Chyba pri pridaní používateľa %s do zoznamu hlásení o zmenách %s';
 $lang['subscr_subscribe_noaddress'] = 'Vaše prihlasovacie meno nemá priradenú žiadnu email adresu, nemôžete byť pridaný do zoznamu hlásení o zmenách';
@@ -290,6 +290,7 @@ $lang['i_policy']              = 'Počiatočná ACL politika';
 $lang['i_pol0']                = 'Otvorená Wiki (čítanie, zápis a nahrávanie pre každého)';
 $lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných užívateľov)';
 $lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných užívateľov)';
+$lang['i_allowreg']            = 'Povolenie samostanej registrácie používateľov';
 $lang['i_retry']               = 'Skúsiť znovu';
 $lang['i_license']             = 'Vyberte licenciu, pod ktorou chcete uložiť váš obsah:';
 $lang['i_license_none']        = 'Nezobrazovať žiadne licenčné informácie';
