@@ -179,7 +179,7 @@ $lang['admin_register']        = 'Shto Përdorues të Ri';
 $lang['metaedit']              = 'Redakto Metadata';
 $lang['metasaveerr']           = 'Shkrimi i metadata-ve dështoi';
 $lang['metasaveok']            = 'Metadata u ruajt';
-$lang['img_backto']            = 'Mbrapa te';
+$lang['btn_img_backto']            = 'Mbrapa te %s';
 $lang['img_title']             = 'Titulli ';
 $lang['img_caption']           = 'Titra';
 $lang['img_date']              = 'Data';
