@@ -201,7 +201,7 @@ $lang['admin_register']        = 'Додај новог корисника';
 $lang['metaedit']              = 'Измени мета-податке';
 $lang['metasaveerr']           = 'Записивање мета-података није било успешно';
 $lang['metasaveok']            = 'Мета-подаци су сачувани';
-$lang['img_backto']            = 'Натраг на';
+$lang['btn_img_backto']            = 'Натраг на %s';
 $lang['img_title']             = 'Наслов';
 $lang['img_caption']           = 'Назив';
 $lang['img_date']              = 'Датум';
