@@ -181,7 +181,7 @@ $lang['admin_register']        = 'สร้างบัญชีผู้ใช
 $lang['metaedit']              = 'แก้ไขข้อมูลเมต้า';
 $lang['metasaveerr']           = 'มีข้อผิดพลาดในการเขียนข้อมูลเมต้า';
 $lang['metasaveok']            = 'บันทึกเมต้าดาต้าแล้ว';
-$lang['img_backto']            = 'กลับไปยัง';
+$lang['btn_img_backto']            = 'กลับไปยัง %s';
 $lang['img_title']             = 'ชื่อภาพ';
 $lang['img_caption']           = 'คำบรรยายภาพ';
 $lang['img_date']              = 'วันที่';
