@@ -223,7 +223,7 @@ $lang['admin_register']        = 'Додати нового користувач
 $lang['metaedit']              = 'Редагувати метадані';
 $lang['metasaveerr']           = 'Помилка запису метаданих';
 $lang['metasaveok']            = 'Метадані збережено';
-$lang['img_backto']            = 'Повернутися до';
+$lang['btn_img_backto']            = 'Повернутися до %s';
 $lang['img_title']             = 'Назва';
 $lang['img_caption']           = 'Підпис';
 $lang['img_date']              = 'Дата';
