@@ -243,7 +243,7 @@ $lang['admin_register']        = '新增使用者';
 $lang['metaedit']              = '編輯後設資料';
 $lang['metasaveerr']           = '後設資料無法寫入';
 $lang['metasaveok']            = '後設資料已儲存';
-$lang['img_backto']            = '回上一頁';
+$lang['btn_img_backto']            = '回上一頁 %s';
 $lang['img_title']             = '標題';
 $lang['img_caption']           = '照片說明';
 $lang['img_date']              = '日期';
@@ -256,7 +256,7 @@ $lang['img_camera']            = '相機';
 $lang['img_keywords']          = '關鍵字';
 $lang['img_width']             = '寬度';
 $lang['img_height']            = '高度';
-$lang['img_manager']           = '在多媒體管理器中檢視';
+$lang['btn_mediaManager']           = '在多媒體管理器中檢視';
 $lang['subscr_subscribe_success'] = '已將 %s 加入至 %s 的訂閱列表';
 $lang['subscr_subscribe_error'] = '將 %s 加入至 %s 的訂閱列表時發生錯誤';
 $lang['subscr_subscribe_noaddress'] = '沒有與您登入相關的地址，無法將您加入訂閱列表';
