@@ -56,7 +56,7 @@ function css_out(){
     }
 
     // cache influencers
-    $tplinc = tpl_basedir($tpl);
+    $tplinc = tpl_incdir($tpl);
     $cache_files = getConfigFiles('main');
     $cache_files[] = $tplinc.'style.ini';
     $cache_files[] = $tplinc.'style.local.ini'; // @deprecated
@@ -70,6 +70,7 @@ function css_out(){
         $files[$mediatype] = array();
         // load core styles
         $files[$mediatype][DOKU_INC.'lib/styles/'.$mediatype.'.css'] = DOKU_BASE.'lib/styles/';
+
         // load jQuery-UI theme
         if ($mediatype == 'screen') {
             $files[$mediatype][DOKU_INC.'lib/scripts/jquery/jquery-ui-theme/smoothness.css'] = DOKU_BASE.'lib/scripts/jquery/jquery-ui-theme/';
@@ -132,6 +133,9 @@ function css_out(){
     $css = ob_get_contents();
     ob_end_clean();
 
+    // strip any source maps
+    stripsourcemaps($css);
+
     // apply style replacements
     $css = css_applystyle($css, $styleini['replacements']);
 
@@ -456,8 +460,9 @@ class DokuCssFile {
             if (defined('DOKU_UNITTEST')) {
                 $basedir[] = realpath(TMP_DIR);
             }
-            $regex = '#^('.join('|',$basedir).')#';
 
+            $basedir = array_map('preg_quote_cb', $basedir);
+            $regex = '/^('.join('|',$basedir).')/';
             $this->relative_path = preg_replace($regex, '', dirname($this->filepath));
         }
 
@@ -550,7 +555,7 @@ function css_compress($css){
     $css = preg_replace_callback('#(/\*)(.*?)(\*/)#s','css_comment_cb',$css);
 
     //strip (incorrect but common) one line comments
-    $css = preg_replace('/(?<!:)\/\/.*$/m','',$css);
+    $css = preg_replace_callback('/^.*\/\/.*$/m','css_onelinecomment_cb',$css);
 
     // strip whitespaces
     $css = preg_replace('![\r\n\t ]+!',' ',$css);
@@ -586,4 +591,41 @@ function css_comment_cb($matches){
     return $matches[0];
 }
 
+/**
+ * Callback for css_compress()
+ *
+ * Strips one line comments but makes sure it will not destroy url() constructs with slashes
+ *
+ * @param $matches
+ * @return string
+ */
+function css_onelinecomment_cb($matches) {
+    $line = $matches[0];
+
+    $out = '';
+    $i = 0;
+    $len = strlen($line);
+    while ($i< $len){
+        $nextcom = strpos($line, '//', $i);
+        $nexturl = stripos($line, 'url(', $i);
+
+        if($nextcom === false) {
+            // no more comments, we're done
+            $out .= substr($line, $i, $len-$i);
+            break;
+        }
+        if($nexturl === false || $nextcom < $nexturl) {
+            // no url anymore, strip comment and be done
+            $out .= substr($line, $i, $nextcom-$i);
+            break;
+        }
+        // we have an upcoming url
+        $urlclose = strpos($line, ')', $nexturl);
+        $out .= substr($line, $i, $urlclose-$i);
+        $i = $urlclose;
+    }
+
+    return $out;
+}
+
 //Setup VIM: ex: et ts=4 :
