@@ -57,7 +57,7 @@
     }
 
     // give info on PHP caught upload errors
-    if($_FILES['upload']['error']){
+    if(!empty($_FILES['upload']['error'])){
         switch($_FILES['upload']['error']){
             case 1:
             case 2:
@@ -71,7 +71,7 @@
     }
 
     // handle upload
-    if($_FILES['upload']['tmp_name']){
+    if(!empty($_FILES['upload']['tmp_name'])){
         $JUMPTO = media_upload($NS,$AUTH);
         if($JUMPTO) $NS = getNS($JUMPTO);
     }
